package com.hp.user.client.service;

import com.hp.user.client.entity.*;


/**
 * <p>
 * 用户信息表 服务类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
public interface AccountService {
	public Result insert(AccountVO account);
	
	public Result addCompnayPersonnelAccount(AccountVO account);
	
	public Result updateCompnayPersonnelAccount(AccountVO account);
	
	public PageResult<AccountVO> queryCompnayPersonnelAccountByPageQuery(PageQuery pageQuery);
	
	public Result deleteCompnayPersonnelAccountById(String userId);
	
	public DataResult<AccountVO> queryCompnayPersonnelAccount(String userId);
	
	public Result bindCompnay(BindCompanyVO bindCompanyVO);
	
	
	public DataResult<AccountVO> queryByUserId(String userId);
	public Result delete(String userId);
	public Result update(AccountVO account);
	public PageResult queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus(String companyId, String userName, String phone, Integer status, Long current, Integer size);
	public Result batchChangeStatusOfUser(String[] userIds,Short status);
	public DataResult<AccountVO> queryAccountByPhone(String phone);

	/**
	 * 登陆
	 * @param phone 手机号
	 * @param verificationCode 验证码
	 */
	public DataResult<String> login(String phone,String verificationCode);
	
	/**
	 * app登陆
	 * @param phone
	 * @param verificationCode
	 * @param cid 终端cid
	 * @return
	 */
	public DataResult<ElectricianVO> appLogin(String phone,String verificationCode,String cid);
	/**
	 * 判断手机号是否注册过
	 * 注册过返回true
	 * 没有注册过返回false
	 * @param phone
	 */
	public Result checkPhone(String phone);
	
	/**
	 * 注册
	 * @param account
	 */
	public DataResult<String> register(AccountVO account);
	
	/**
	 * 绑定微信号
	 * @param userId 用户id
	 * @param wxNumber 微信号
	 */
	public void bindWx(String userId,String wxNumber);
	
	/**
	 * 微信授权登陆
	 */
	public DataResult<AccountVO> wxAuthorization(AccountVO account,String wxCode);
	
	/**
	 * 通过微信注册
	 * @param account
	 * @param verificationCode 验证码
	 * @return
	 */
	public DataResult<AccountVO> wxRegister(AccountVO account,String verificationCode);
	
	/**
	 * 通过session获取用户信息
	 * @return
	 */
	public DataResult<Object> queryUserBySession();
	
	/**
	 * 保存微信信息
	 * @param account
	 * @return
	 */
	public Result saveWxInfo(AccountVO account);
	
	public DataResult<String> serviceProviderLogin(String phone,String verificationCode);
	
	public DataResult<String> backstageLogin(String phone,String verificationCode);

}
