package com.hp.user.client.service;


import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.HighVoltageCabinetVO;
import com.hp.user.client.entity.HighVoltageDrawerVO;
import com.hp.user.client.entity.InspectionContentVO;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.LowVoltageCabinetVO;
import com.hp.user.client.entity.LowVoltageDrawerVO;
import com.hp.user.client.entity.Result;
import com.hp.user.client.entity.SubstationVO;
import com.hp.user.client.entity.TransformerVO;
import com.hp.user.client.entity.TreeVO;


public interface DeviceManagerService {
	
	
	public Result createSubstation(SubstationVO substationVO);
	public ListResult<SubstationVO> querySubstationByStationId(String stationId);
	public Result updateSubstation( SubstationVO substationVO);
	
	public DataResult<SubstationVO> querySubstationById(String id);
	
	
	/**
	 * 创建变压器
	 * @param transformerVO
	 * @return
	 */
	public Result createTransformer(TransformerVO transformerVO);
	
	/**
	 * 更新变压器
	 * @param TransformerVO
	 * @return
	 */
	public Result updateTransformer(TransformerVO TransformerVO);
	
	/**
	 * 根据配电房id查询变压器
	 * @param subStationId
	 * @return
	 */
	public ListResult<TransformerVO> queryTransformerBySubStationId(String subStationId);
	
	/**
	 * 创建高压柜
	 * @param highVoltageCabinetVO
	 * @return
	 */
	public Result createHighVoltageCabinet(HighVoltageCabinetVO highVoltageCabinetVO);
	/**
	 * 根据配电房id查询高压柜
	 * @param subStationId
	 * @return
	 */
	public ListResult<HighVoltageCabinetVO> queryHighVoltageCabinetBySubStationId(String subStationId);
	/**
	 * 更新高压柜
	 * @param highVoltageCabinetVO
	 * @return
	 */
	public Result updateHighVoltageCabinet(HighVoltageCabinetVO highVoltageCabinetVO);
	
	/**
	 * 添加低压柜
	 * @param lowVoltageCabinetVO
	 * @return
	 */
	public Result createLowVoltageCabinet(LowVoltageCabinetVO lowVoltageCabinetVO);
	
	/**
	 * 根据配电房id查询低压柜
	 * @param subStationId
	 * @return
	 */
	public ListResult<LowVoltageCabinetVO> queryLowVoltageCabinetBySubStationId(String subStationId);
	
	/**
	 * 更新低压柜
	 * @param lowVoltageCabinetVO
	 * @return
	 */
	public Result updateLowVoltageCabinet(LowVoltageCabinetVO lowVoltageCabinetVO);
	
	/**
	 * 创建高压柜抽屉
	 * @param highVoltageDrawerVO
	 * @return
	 */
	public Result createHighVoltageCabinetDrawer(HighVoltageDrawerVO highVoltageDrawerVO);
	/**
	 * 修改高压柜抽屉
	 * @param highVoltageDrawerVO
	 * @return
	 */
	public Result updateHighVoltageCabinetDrawer(HighVoltageDrawerVO highVoltageDrawerVO);
	/**
	 * 查询高压柜抽屉
	 * @param cabinetId
	 * @return
	 */
	public ListResult<HighVoltageDrawerVO> queryHighVoltageCabinetDrawerByCabinetId(String cabinetId);
	
	/**
	 * 创建低压柜抽屉
	 * @param lowVoltageDrawerVO
	 * @return
	 */
	public Result createLowVoltageCabinetDrawer(LowVoltageDrawerVO lowVoltageDrawerVO);
	
	/**
	 * 修改低压压柜抽屉
	 * @param highVoltageDrawerVO
	 * @return
	 */
	public Result updateLowVoltageCabinetDrawer(LowVoltageDrawerVO lowVoltageDrawerVO);
	
	/**
	 * 查询低压柜抽屉
	 * @param cabinetId
	 * @return
	 */
	public ListResult<LowVoltageDrawerVO> queryLowVoltageCabinetDrawerByCabinetId(String cabinetId);
	
	public DataResult<LowVoltageDrawerVO> queryLowVoltageDrawerById(String Id);
	
	public DataResult<HighVoltageDrawerVO> queryHighVoltageDrawerById(String Id);
	
	public DataResult<LowVoltageCabinetVO> queryLowVoltageCabinetById(String Id);
	
	public DataResult<HighVoltageCabinetVO> queryHighVoltageCabinetById(String Id);
	
	public DataResult<TransformerVO> queryTransformerById(String Id);
	
	/**
	 * 根据设备类型id查询巡检项
	 * @param deviceTypeId
	 * @return
	 */
	public ListResult<InspectionContentVO> queryInspectionContentByTypeId(String deviceTypeId);
	
	/**
	 * 查询其它巡检项
	 * @return
	 */
	public ListResult<InspectionContentVO> queryOtherInspectionContent();
	/**
	 * 根据设备id查询设备巡检项
	 * @param deviceId
	 * @return
	 */
	public ListResult<InspectionContentVO> queryInspectionContentByDeviceId(String deviceId);
	
	/**
	 * 根据设备id查询设备信息
	 * @param deviceId
	 * @return
	 */
	public DataResult<Object> querydeviceInfoByDeviceId(String deviceId);
	
	public ListResult<TreeVO> queryLowerDeviceByParentId(String parentId);
}
