package com.hp.user.client.service;

import java.util.List;
import java.util.Map;

import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.ElectricianVO;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.PageQuery;
import com.hp.user.client.entity.PageResult;
import com.hp.user.client.entity.Result;

public interface ElectricianService {
	
	/**
	 * 创建电工
	 * @param electricianVO 电工信息
	 * @return
	 */
	public Result createElectrician(ElectricianVO electricianVO);
	
	/**
	 * 查询电工
	 * @param query 查询条件
	 * @return
	 */
	public PageResult<ElectricianVO> queryElectrician(PageQuery query);
	
	public PageResult<ElectricianVO> queryServiceProviderElectrician(PageQuery query);
	
	/**
	 * 修改电工信息
	 * @param electricianVO
	 * @return
	 */
	public Result updateElectrician(ElectricianVO electricianVO);
	
	/**
	 * 根据id查询电工
	 * @param electricianId 电工id
	 * @return
	 */
	public DataResult<ElectricianVO> queryElectricianById(String electricianId);
	
	/**
	 * 批量修改电工状态
	 * @param electricianIds 电工id
	 * @param status 状态
	 * @return
	 */
	public Result updateStatusBatch(String[] electricianIds,Integer status);
	
	/**
	 * 删除电工
	 * @param electricianId 电工id
	 * @return
	 */
	public Result deleteElectricianById(String electricianId);
	
	/**
	 * 根据用户id查询电工信息
	 * @param userId
	 * @return
	 */
	public DataResult<ElectricianVO> queryElectricianByUserId(String userId);
	
	public Result updateElectricianCid(String electricianId,String cid);
	
	/**
	 * 根据id列表查询电工
	 * @param ids
	 * @return
	 */
	public ListResult<ElectricianVO> queryElectricianByUserIds(List<String> ids);
	/**
	 * 更新电工位置
	 * @param electricianId 电工id
	 * @param lng 经度
	 * @param lat 纬度
	 * @return
	 */
	public Result updateLocation(String electricianId,String lng,String lat);
	
	public ListResult<ElectricianVO> queryAssignElectrician(String address);
	
	public DataResult<ElectricianVO> electricianLogin(String phone,String verificationCode,String cid);
	
	public Result updateWorkStatus(String electricianIds,Integer status);
	
	public ListResult<ElectricianVO> queryByServiceProviderCityCode(String cityCode,Double lng,Double lat);
	public ListResult<ElectricianVO> queryByServiceProviderCountCode(String countCode,Double lng,Double lat);
	public ListResult<ElectricianVO> queryElectricianByServiceProviderId(String serviceProviderId,String groupId);
	
	public ListResult<ElectricianVO> queryAccompanyingElectrician(PageQuery query);
	
	/**
	 * 查询所属服务商的折扣
	 * @param electricianId
	 * @return
	 */
	public DataResult<String> queryServiceProviderDiscountByElectricianId(String electricianId);
}
