package com.hp.user.client.service;


import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.entity.SurveyDcScreenVO;
import com.hp.user.client.entity.SurveyHighVoltageSwitchCabinetVO;
import com.hp.user.client.entity.SurveyLowVoltageSwitchCabinetVO;
import com.hp.user.client.entity.SurveyReactivePowerCompensationVO;
import com.hp.user.client.entity.SurveySubstationDeviceVO;
import com.hp.user.client.entity.SurveySubstationVO;
import com.hp.user.client.entity.SurveyTransformerVO;


/**
 * 勘察设备管理
 * @author yeqid
 *
 */
public interface SurveyDeviceManagerService {

	/**
	 * 添加配电房
	 * @param surveySubstationVO
	 * @return
	 */
	public Result createSubstation(SurveySubstationVO surveySubstationVO);
	
	/**
	 * 根据站点id查询配电房
	 * @param stationId
	 * @return
	 */
	public ListResult<SurveySubstationVO> querySubstationByStationId(String stationId);
	
	/**
	 * 更新配电房
	 * @param surveySubstationVO
	 * @return
	 */
	public Result updateSubstation(SurveySubstationVO surveySubstationVO);
	
	/**
	 * 添加变压器
	 * @param surveyTransformerVO
	 * @return
	 */
	public Result createTransformer(SurveyTransformerVO surveyTransformerVO);
	
	/**
	 * 根据配电房id查询变压器
	 * @param subStationId
	 * @return
	 */
	public ListResult<SurveyTransformerVO> queryTransformerBySubStationId(String subStationId);
	
	/**
	 * 更新变压器
	 * @param surveyTransformerVO
	 * @return
	 */
	public Result updateTransformer(SurveyTransformerVO surveyTransformerVO);
	
	
	/**
	 * 添加高压开关柜
	 * @param surveyHighVoltageSwitchCabinetVO
	 * @return
	 */
	public Result createSurveyHighVoltageSwitchCabinet(SurveyHighVoltageSwitchCabinetVO surveyHighVoltageSwitchCabinetVO);
	
	/**
	 * 根据配电房id查看高压开关柜
	 * @param subStationId
	 * @return
	 */
	public ListResult<SurveyHighVoltageSwitchCabinetVO> querySurveyHighVoltageSwitchCabinetBySubStationId(String subStationId);
	
	/**
	 * 更新高压开关柜
	 * @param surveyHighVoltageSwitchCabinetVO
	 * @return
	 */
	public Result updateHighVoltageSwitchCabinet(SurveyHighVoltageSwitchCabinetVO surveyHighVoltageSwitchCabinetVO);
	/**
	 * 添加低压开关柜
	 * @param surveyLowVoltageSwitchCabinetVO
	 * @return
	 */
	public Result createSurveyLowVoltageSwitchCabinet(SurveyLowVoltageSwitchCabinetVO surveyLowVoltageSwitchCabinetVO);
	/**
	 * 根据配电房id查看低压开关柜
	 * @param subStationId
	 * @return
	 */
	public ListResult<SurveyLowVoltageSwitchCabinetVO> querySurveyLowVoltageSwitchCabinetBySubStationId(String subStationId);
	
	/**
	 * 更新低压开关柜
	 * @param surveyLowVoltageSwitchCabinetVO
	 * @return
	 */
	public Result updateLowVoltageSwitchCabinet(SurveyLowVoltageSwitchCabinetVO surveyLowVoltageSwitchCabinetVO);
	
	/**
	 * 添加无功补偿设备
	 * @param surveyReactivePowerCompensationVO
	 * @return
	 */
	public Result createReactivePowerCompensation(SurveyReactivePowerCompensationVO surveyReactivePowerCompensationVO);
	
	/**
	 * 根据配电房id查看无功补偿设备
	 * @param subStationId
	 * @return
	 */
	public ListResult<SurveyReactivePowerCompensationVO> queryReactivePowerCompensationBySubStationId(String subStationId);
	
	/**
	 * 更新无功补偿设备
	 * @param surveyReactivePowerCompensationVO
	 * @return
	 */
	public Result updateReactivePowerCompensation(SurveyReactivePowerCompensationVO surveyReactivePowerCompensationVO);
	
	/**
	 * 添加直流屏
	 * @param surveyDcScreenVO
	 * @return
	 */
	public Result createDcScreen(SurveyDcScreenVO surveyDcScreenVO);
	
	/**
	 * 根据配电房id查看直流屏
	 * @param subStationId
	 * @return
	 */
	public ListResult<SurveyDcScreenVO> queryDcScreenBySubStationId(String subStationId);
	
	/**
	 * 更新直流屏
	 * @param surveyDcScreenVO
	 * @return
	 */
	public Result updateDcScreen(SurveyDcScreenVO surveyDcScreenVO);
	
	/** 
	 * 根据配电房id查询配电房中全部勘察设备
	 * @param surveySubstationDevice
	 * @return
	 */
	public ListResult<SurveySubstationDeviceVO> querySubstionAllDeviceBySubstationId(String substationId);
	
	ListResult<Object> querySubstionAllDeviceInfoBySubstationId(String substationId);
}
