package com.hp.user.service.controller;

import com.hp.user.client.entity.AddressVO;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.AddressService;
import com.hp.user.service.utils.IdWorker;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Api(tags = "地址API接口")
@RestController
@RequestMapping("/user/address")
public class AddressController {
    @Autowired
    private AddressService addressService;

    /**
     * 添加地址
     * @param address 地址信息
     * @return Result
     */
    @ApiOperation(value = "新增地址")
    @PostMapping("/addAddress")
    public Result addAddress(@RequestBody AddressVO address){
        address.setAddressId(IdWorker.generactorId().toString());
        return addressService.insert(address);
    }

    /**
     * 查询所有地址信息
     * @return ListResult
     */
    @ApiOperation(value = "查询所有地址信息")
    @GetMapping("/queryAllAddress")
    public ListResult<AddressVO> queryAllAddress(){
        return addressService.queryAllAddress();
    }
    
    /**
     * 更新地址信息
     * @return ListResult
     */
    @ApiOperation(value = "更新地址信息")
    @PostMapping("/updateAddress")
    public Result updateAddress(@RequestBody AddressVO address){
        return addressService.update(address);
    }
    
    /**
     * 根据ownerId查询地址
     * @param address
     * @return
     */
    @ApiOperation(value = "根据ownerId查询地址")
    @GetMapping("/queryAddressByOwnerId")
    public ListResult<AddressVO> queryAddressByOwnerId(String ownerId){
        return addressService.queryAddressByOwnerId(ownerId);
    }
    
    /**
     * 根据地址id查询地址信息
     */
    @ApiOperation(value = "根据地址id查询地址信息")
    @GetMapping("/queryAddressByAddressId")
    public DataResult<AddressVO> queryAddressByAddressId(String addressId){
        return addressService.queryAddressByAddressId(addressId);
    }
    
    /**
     * 删除地址
     */
    @ApiOperation(value = "删除地址")
    @GetMapping("/deleteAddressByAddressId")
    public Result deleteAddressByAddressId(String addressId) {
    	return addressService.deleteAddressByAddressId(addressId);
    }
}
