package com.hp.user.service.controller;

import java.util.Map;

import org.apache.dubbo.config.annotation.Reference;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.ElectricianVO;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.PageQuery;
import com.hp.user.client.entity.PageResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.ElectricianService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@Api(tags="电工")
@RestController
@RequestMapping("/user/electrician")
public class ElectricianController {
	
	@Reference
	private ElectricianService electricianService;
	
	/**
	 * 添加电工
	 * @param electrician
	 * @return
	 */
	@RequestMapping("/createElectrician")
    @ApiOperation(value = "添加电工", notes = "添加电工", httpMethod = "POST")
	public Result createElectrician(@RequestBody ElectricianVO electrician) {
		return electricianService.createElectrician(electrician);
	}
	
	/**
	 * 根据条件查询电工
	 * 如果page设置为-1，则不进行分页查询
	 * @param query
	 * @return
	 */
	@RequestMapping("/queryElectrician")
    @ApiOperation(value = "根据条件查询电工", notes = "根据条件查询电工", httpMethod = "POST")
	public PageResult<ElectricianVO> queryElectrician(@RequestBody PageQuery query) {
		return electricianService.queryElectrician(query);
	}
	
	/**
	 * 根据条件查询电工
	 * 如果page设置为-1，则不进行分页查询
	 * @param query
	 * @return
	 */
	@RequestMapping("/queryServiceProviderElectrician")
    @ApiOperation(value = "根据条件查询服务商电工", notes = "根据条件查询服务商电工", httpMethod = "POST")
	public PageResult<ElectricianVO> queryServiceProviderElectrician(@RequestBody PageQuery query) {
		return electricianService.queryServiceProviderElectrician(query);
	}
	
	/**
	 * 修改电工
	 * @param query
	 * @return
	 */
	@RequestMapping("/updateElectrician")
    @ApiOperation(value = "修改电工", notes = "修改电工", httpMethod = "POST")
	public Result updateElectrician(@RequestBody ElectricianVO electrician) {
		return electricianService.updateElectrician(electrician);
	}
	
	/**
	 * 根据id查询电工
	 * @param query
	 * @return
	 */
	@RequestMapping("/queryElectricianById")
    @ApiOperation(value = "根据id查询电工", notes = "根据id查询电工", httpMethod = "POST")
	public DataResult<ElectricianVO> queryElectricianById(String electricianId) {
		return electricianService.queryElectricianById(electricianId);
	}
	
	/**
	 * 批量修改员工状态
	 * @param electricianIds 电工ids
	 * @param status 电工状态
	 * @return
	 */
	@RequestMapping("/updateStatusBatch")
    @ApiOperation(value = "批量修改员工状态", notes = "批量修改员工状态", httpMethod = "POST")
	public Result updateStatusBatch(@RequestBody String[] electricianIds,Integer status) {
		return electricianService.updateStatusBatch(electricianIds, status);
	}
	
	/**
	 * 删除电工
	 * @param electricianId 电工id
	 * @return
	 */
	@RequestMapping("/deleteElectricianById")
    @ApiOperation(value = "删除电工", notes = "删除电工", httpMethod = "POST")
	public Result deleteElectricianById(String electricianId) {
		return electricianService.deleteElectricianById(electricianId);
	}
	
	/**
	 * 更新电工位置
	 * @param electricianId 电工id
	 * @param lng 经度
	 * @param lat 纬度
	 * @return
	 */
	@RequestMapping("/updateLocation")
    @ApiOperation(value = "更新电工位置", notes = "更新电工位置", httpMethod = "POST")
	public Result updateLocation(String electricianId,String lng,String lat) {
		return electricianService.updateLocation(electricianId,lng,lat);
	}
	
	/**
	 * 查询可指派电工
	 * @param workOrderAddress
	 * @return
	 */
	@RequestMapping("/queryAssignElectrician")
    @ApiOperation(value = "查询可指派电工", notes = "查询可指派电工", httpMethod = "POST")
	public ListResult<ElectricianVO> queryAssignElectrician(String workOrderAddress) {
		return electricianService.queryAssignElectrician(workOrderAddress);
	}
	
	/**
	 * 电工登陆
	 * @param phone
	 * @param verificationCode
	 * @param cid
	 * @return
	 */
	@RequestMapping("/electricianLogin")
    @ApiOperation(value = "电工登陆", notes = "电工登陆", httpMethod = "POST")
	public DataResult<ElectricianVO> electricianLogin(String phone,String verificationCode,String cid) {
		return electricianService.electricianLogin(phone, verificationCode, cid);
	}
	/**
	 * 根据服务商查电工
	 * @param phone
	 * @param verificationCode
	 * @param cid
	 * @return
	 */
	@RequestMapping("/queryElectricianByServiceProviderId")
    @ApiOperation(value = "根据服务商查电工", notes = "根据服务商查电工", httpMethod = "POST")
	public ListResult<ElectricianVO> queryElectricianByServiceProviderId(String serviceProviderId,String groupId) {
		return electricianService.queryElectricianByServiceProviderId(serviceProviderId,groupId);
	}
	
	
	@RequestMapping("/queryAccompanyingElectrician")
    @ApiOperation(value = "查询随行电工", notes = "查询随行电工", httpMethod = "POST")
	public ListResult<ElectricianVO> queryAccompanyingElectrician(@RequestBody PageQuery query) {
		return electricianService.queryAccompanyingElectrician( query);
	}
	
}
