package com.hp.user.service.controller;

import org.apache.dubbo.config.annotation.Reference;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.InspectionPlanVO;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.PageQuery;
import com.hp.user.client.entity.PageResult;
import com.hp.user.client.entity.PlanForUserVO;
import com.hp.user.client.entity.PlanVO;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.InspectionPlanService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

/**
 * 巡检计划
 * @author yeqid
 *
 */
@Api(tags = "巡检计划")
@RestController
@RequestMapping("/user/inspectionPlan")
public class InspectionPlanController {
	
	@Reference
	private InspectionPlanService inspectionPlanService;
	
	@RequestMapping("/createInspectionPlan")
	@ApiOperation(value ="添加巡检计划", notes = "添加巡检计划", httpMethod = "POST")
	public Result createInspectionPlan(@RequestBody @ApiParam(name="巡检计划对象",required=true) InspectionPlanVO inspectionPlanVO) {
		return inspectionPlanService.createInspectionPlan(inspectionPlanVO);
	}
	
	@RequestMapping("/updateInspectionPlan")
	@ApiOperation(value ="修改巡检计划", notes = "修改巡检计划", httpMethod = "POST")
	public Result updateInspectionPlan(@RequestBody InspectionPlanVO inspectionPlanVO) {
		return inspectionPlanService.updateInspectionPlan(inspectionPlanVO);
	}
	
	@RequestMapping("/deleteInspectionPlan")
	@ApiOperation(value ="删除巡检计划", notes = "删除巡检计划", httpMethod = "GET")
	public Result deleteInspectionPlan(String planId) {
		return inspectionPlanService.deleteInspectionPlan(planId);
	}
	
	@RequestMapping("/queryInspectionPlanByPageQuery")
	@ApiOperation(value ="根据条件查询巡检计划", notes = "根据条件查询巡检计划", httpMethod = "POST")
	public PageResult<PlanVO> queryInspectionPlanByPageQuery(@RequestBody PageQuery query) {
		return inspectionPlanService.queryInspectionPlanByPageQuery(query);
	}
	
	@RequestMapping("/queryInspectionPlanById")
	@ApiOperation(value ="根据id查询巡检计划", notes = "根据id查询巡检计划", httpMethod = "GET")
	public DataResult<InspectionPlanVO> queryInspectionPlanById(String planId) {
		return inspectionPlanService.queryInspectionPlanById(planId);
	}
	@RequestMapping("/queryInspectionPlanByCompanyId")
	@ApiOperation(value ="根据公司id查询巡检计划", notes = "根据公司id查询巡检计划", httpMethod = "GET")
	public ListResult<PlanForUserVO> queryInspectionPlanByCompanyId(String companyId) {
		return inspectionPlanService.queryInspectionPlanByCompanyId(companyId);
	}
	
	@RequestMapping("/distribution")
	@ApiOperation(value ="计划指派", notes = "计划指派", httpMethod = "GET")
	@ApiImplicitParams({
		  @ApiImplicitParam(name="planId",value="计划id",dataType="string", paramType = "query"),
		  @ApiImplicitParam(name="groupId",value="班组id",dataType="string", paramType = "query"),
		  @ApiImplicitParam(name="electricianIds",value="电工ID，多个用','隔开",dataType="string", paramType = "query")})
	public Result distribution(String planId,String groupId,String electricianIds) {
		return inspectionPlanService.distribution(planId,groupId,electricianIds);
	}
}
