package com.hp.user.service.controller;

import com.hp.user.client.entity.*;
import com.hp.user.client.service.StationService;
import com.hp.user.service.utils.IdWorker;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import org.apache.dubbo.config.annotation.Reference;
import org.springframework.web.bind.annotation.*;

@Api(tags = "站点API接口")
@RestController
@RequestMapping("/user/station")
public class StationController {
    @Reference
    private StationService stationService;

    /**
     * 添加站点
     *
     * @param station 站点信息
     * @return Result
     */
    @ApiOperation(value = "新增站点")
    @PostMapping("/addStation")
    public Result addStation(@RequestBody StationVO station) {
        station.setStationId(IdWorker.generactorId().toString());
        return stationService.insert(station);
    }

    /**
     * 更新站点信息
     *
     * @param station 站点信息
     * @return Result
     */
    @ApiOperation(value = "更新站点信息")
    @PostMapping("/updateStation")
    public Result updateStation(@RequestBody StationVO station) {
        return stationService.update(station);
    }

    /**
     * 根据站点Id删除站点
     *
     * @param stationId 站点Id
     * @return Result
     */
    @ApiOperation(value = "删除站点")
    @GetMapping("/deleteStationByStationId")
    public Result deleteStationByStationId(@RequestParam String stationId) {
        return stationService.delete(stationId);
    }

    /**
     * 根据站点Id查询某站点信息
     *
     * @param stationId 站点Id
     * @return DataResult
     */
    @ApiOperation(value = "根据站点Id查询某站点")
    @GetMapping("/queryStationByStationId")
    public DataResult<StationVO> queryStationByStationId(String stationId) {
        return stationService.queryStationByStationId(stationId);
    }

    /**
     * 根据站点名称查询某站点信息
     *
     * @param stationName 站点名称
     * @return DataResult
     */
    @ApiOperation(value = "根据站点名称查询某站点")
    @GetMapping("/queryStationByStationName")
    public DataResult<StationVO> queryStationByStationName(String stationName) {
        return stationService.queryStationByStationName(stationName);
    }

    /**
     * 查询所有站点信息
     */
    /**
     * 分页查询所有站点信息
     *
     * @param current 要查询页数
     * @param size    一页的行数
     * @return PageResult
     */
    @ApiOperation(value = "根据企业Id、站点名称分页查询所有站点", notes = "输入的current为要查询的页数，size为一页的行数，返回的total为总行数")
    @GetMapping("/queryStationsPageByCompanyIdAndStationName")
    public PageResult<StationVO> queryStationsPageByCompanyIdAndStationName(@RequestParam String companyId,String stationName,@RequestParam Long current, @RequestParam Integer size) {
        return stationService.queryAllStationsPageByCompanyIdAndStationName(companyId,stationName,current, size);
    }
    
    @ApiOperation(value = "根据服务商id查询站点", notes = "根据服务商id查询站点")
    @GetMapping("/queryStationsByServiceProviderId")
    public ListResult<StationVO> queryStationsByServiceProviderId(String serviceProviderId) {
        return stationService.queryStationsByServiceProviderId(serviceProviderId);
    }
}
