package com.hp.user.service.controller;

import org.apache.dubbo.config.annotation.Reference;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.entity.SurveyDcScreenVO;
import com.hp.user.client.entity.SurveyHighVoltageSwitchCabinetVO;
import com.hp.user.client.entity.SurveyLowVoltageSwitchCabinetVO;
import com.hp.user.client.entity.SurveyReactivePowerCompensationVO;
import com.hp.user.client.entity.SurveySubstationDeviceVO;
import com.hp.user.client.entity.SurveySubstationVO;
import com.hp.user.client.entity.SurveyTransformerVO;
import com.hp.user.client.service.SurveyDeviceManagerService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@Api(tags = "勘察设备管理")
@RestController
@RequestMapping("/user/surveyDevice")
public class SurveyDeviceMangerController {
	
	@Reference
	private SurveyDeviceManagerService surveyDeviceManagerService;
	
	
	@ApiOperation(value = "添加配电房" ,notes = "添加配电房", httpMethod = "POST")
	@RequestMapping("/createSubstation")
	public Result createSubstation(@RequestBody SurveySubstationVO surveySubstationVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.createSubstation(surveySubstationVO);
		return result;
	}
	
	@ApiOperation(value = "根据站点查询配电房" ,notes = "根据站点查询配电房", httpMethod = "GET")
	@RequestMapping("/querySubstationByStationId")
	public ListResult<SurveySubstationVO> querySubstationByStationId(String stationId) {
		ListResult<SurveySubstationVO> result = new ListResult<SurveySubstationVO>();
		result = surveyDeviceManagerService.querySubstationByStationId(stationId);
		return result;
	}
	
	@ApiOperation(value = "更新配电房" ,notes = "更新配电房", httpMethod = "POST")
	@RequestMapping("/updateSubstation")
	public Result updateSubstation(@RequestBody SurveySubstationVO surveySubstationVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.updateSubstation(surveySubstationVO);
		return result;
	}
	
	@ApiOperation(value = "添加变压器" ,notes = "添加变压器", httpMethod = "POST")
	@RequestMapping("/createTransformer")
	public Result createTransformer(@RequestBody SurveyTransformerVO surveyTransformerVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.createTransformer(surveyTransformerVO);
		return result;
	}
	
	@ApiOperation(value = "根据配电id查询变压器" ,notes = "根据配电id查询变压器", httpMethod = "GET")
	@RequestMapping("/queryTransformerBySubStationId")
	public ListResult<SurveyTransformerVO> queryTransformerBySubStationId(String subStationId) {
		ListResult<SurveyTransformerVO> result = new ListResult<SurveyTransformerVO>();
		result = surveyDeviceManagerService.queryTransformerBySubStationId(subStationId);
		return result;
	}
	
	@ApiOperation(value = "更新变压器" ,notes = "更新变压器", httpMethod = "POST")
	@RequestMapping("/updateTransformer")
	public Result updateTransformer(@RequestBody SurveyTransformerVO surveyTransformerVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.updateTransformer(surveyTransformerVO);
		return result;
	}
	
	@ApiOperation(value = "添加高压开关柜" ,notes = "添加高压开关柜", httpMethod = "POST")
	@RequestMapping("/createSurveyHighVoltageSwitchCabinet")
	public Result createSurveyHighVoltageSwitchCabinet(@RequestBody SurveyHighVoltageSwitchCabinetVO surveyHighVoltageSwitchCabinetVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.createSurveyHighVoltageSwitchCabinet(surveyHighVoltageSwitchCabinetVO);
		return result;
	}
	
	@ApiOperation(value = "根据配电id查询高压开关柜" ,notes = "根据配电id查询高压开关柜", httpMethod = "GET")
	@RequestMapping("/querySurveyHighVoltageSwitchCabinetBySubStationId")
	public ListResult<SurveyHighVoltageSwitchCabinetVO> querySurveyHighVoltageSwitchCabinetBySubStationId(String subStationId) {
		ListResult<SurveyHighVoltageSwitchCabinetVO> result = new ListResult<SurveyHighVoltageSwitchCabinetVO>();
		result = surveyDeviceManagerService.querySurveyHighVoltageSwitchCabinetBySubStationId(subStationId);
		return result;
	}
	
	@ApiOperation(value = "更新高压开关柜" ,notes = "更新高压开关柜", httpMethod = "POST")
	@RequestMapping("/updateHighVoltageSwitchCabinet")
	public Result updateHighVoltageSwitchCabinet(@RequestBody SurveyHighVoltageSwitchCabinetVO surveyHighVoltageSwitchCabinetVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.updateHighVoltageSwitchCabinet(surveyHighVoltageSwitchCabinetVO);
		return result;
	}
	
	@ApiOperation(value = "添加低压开关柜" ,notes = "添加低压开关柜", httpMethod = "POST")
	@RequestMapping("/createSurveyLowVoltageSwitchCabinet")
	public Result createSurveyLowVoltageSwitchCabinet(@RequestBody SurveyLowVoltageSwitchCabinetVO surveyLowVoltageSwitchCabinetVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.createSurveyLowVoltageSwitchCabinet(surveyLowVoltageSwitchCabinetVO);
		return result;
	}
	
	@ApiOperation(value = "根据配电id查询低压开关柜" ,notes = "根据配电id查询低压开关柜", httpMethod = "GET")
	@RequestMapping("/querySurveyLowVoltageSwitchCabinetBySubStationId")
	public ListResult<SurveyLowVoltageSwitchCabinetVO> querySurveyLowVoltageSwitchCabinetBySubStationId(String subStationId) {
		ListResult<SurveyLowVoltageSwitchCabinetVO> result = new ListResult<SurveyLowVoltageSwitchCabinetVO>();
		result = surveyDeviceManagerService.querySurveyLowVoltageSwitchCabinetBySubStationId(subStationId);
		return result;
	}
	
	@ApiOperation(value = "更新低压开关柜" ,notes = "更新低压开关柜", httpMethod = "POST")
	@RequestMapping("/updateLowVoltageSwitchCabinet")
	public Result updateLowVoltageSwitchCabinet(@RequestBody SurveyLowVoltageSwitchCabinetVO surveyLowVoltageSwitchCabinetVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.updateLowVoltageSwitchCabinet(surveyLowVoltageSwitchCabinetVO);
		return result;
	}
	
	@ApiOperation(value = "添加无功补偿设备" ,notes = "添加无功补偿设备", httpMethod = "POST")
	@RequestMapping("/createReactivePowerCompensation")
	public Result createReactivePowerCompensation(@RequestBody SurveyReactivePowerCompensationVO surveyReactivePowerCompensationVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.createReactivePowerCompensation(surveyReactivePowerCompensationVO);
		return result;
	}
	
	@ApiOperation(value = "根据配电id查询无功补偿设备" ,notes = "根据配电id查询无功补偿设备", httpMethod = "GET")
	@RequestMapping("/queryReactivePowerCompensationBySubStationId")
	public ListResult<SurveyReactivePowerCompensationVO> queryReactivePowerCompensationBySubStationId(String subStationId) {
		ListResult<SurveyReactivePowerCompensationVO> result = new ListResult<SurveyReactivePowerCompensationVO>();
		result = surveyDeviceManagerService.queryReactivePowerCompensationBySubStationId(subStationId);
		return result;
	}
	
	@ApiOperation(value = "更新无功补偿设备" ,notes = "更新无功补偿设备", httpMethod = "POST")
	@RequestMapping("/updateReactivePowerCompensation")
	public Result updateReactivePowerCompensation(@RequestBody SurveyReactivePowerCompensationVO surveyReactivePowerCompensationVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.updateReactivePowerCompensation(surveyReactivePowerCompensationVO);
		return result;
	}
	
	@ApiOperation(value = "添加直流屏" ,notes = "添加直流屏", httpMethod = "POST")
	@RequestMapping("/createDcScreen")
	public Result createDcScreen(@RequestBody SurveyDcScreenVO surveyDcScreenVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.createDcScreen(surveyDcScreenVO);
		return result;
	}
	
	@ApiOperation(value = "根据配电id查询直流屏" ,notes = "根据配电id查询直流屏", httpMethod = "GET")
	@RequestMapping("/queryDcScreenBySubStationId")
	public ListResult<SurveyDcScreenVO> queryDcScreenBySubStationId(String subStationId) {
		ListResult<SurveyDcScreenVO> result = new ListResult<SurveyDcScreenVO>();
		result = surveyDeviceManagerService.queryDcScreenBySubStationId(subStationId);
		return result;
	}
	
	@ApiOperation(value = "更新直流屏" ,notes = "更新直流屏", httpMethod = "POST")
	@RequestMapping("/updateDcScreen")
	public Result updateDcScreen(@RequestBody SurveyDcScreenVO surveyDcScreenVO) {
		Result result = new Result();
		result = surveyDeviceManagerService.updateDcScreen(surveyDcScreenVO);
		return result;
	}
	
	@RequestMapping("/querySubstionAllDeviceBySubstationId")
	@ApiOperation(value = "根据配电房id查询全部勘察设备",notes ="根据配电房id查询全部勘察设备",httpMethod = "GET" )
	public ListResult<SurveySubstationDeviceVO> querySubstionAllDeviceBySubstationId(String substationId) {
		return surveyDeviceManagerService.querySubstionAllDeviceBySubstationId(substationId);
	}
	
	@RequestMapping("/querySubstionAllDeviceInfoBySubstationId")
	@ApiOperation(value = "根据配电房id查询全部勘察设备具体信息",notes ="根据配电房id查询全部勘察设备具体信息",httpMethod = "GET" )
	public ListResult<Object> querySubstionAllDeviceInfoBySubstationId(String substationId) {
		return surveyDeviceManagerService.querySubstionAllDeviceInfoBySubstationId(substationId);
	}
	
	
}
