package com.hp.user.service.controller;

import com.hp.user.client.entity.*;
import com.hp.user.client.service.AccountService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import org.apache.dubbo.config.annotation.Reference;
import org.springframework.web.bind.annotation.*;

@Api(tags = "账号API接口")
@RestController
@RequestMapping("/user/user")
public class UserController {
	@Reference
    private AccountService accountService;

    /**
     * 添加用户
     *
     * @param user 用户信息
     * @return Result
     */
    @ApiOperation(value = "新增账户", notes = "提示：要指定账号对应的服务商", httpMethod = "POST")
    @PostMapping("/addUser")
    public Result addUser(@RequestBody AccountVO user) {
        return accountService.insert(user);
    }
    
    @ApiOperation(value = "新增企业员工账户", notes = "新增企业员工账户", httpMethod = "POST")
    @PostMapping("/addCompnayPersonnelAccount")
    public Result addCompnayPersonnelAccount(@RequestBody AccountVO user) {
        return accountService.addCompnayPersonnelAccount(user);
    }

    @ApiOperation(value = "查询企业员工账户", notes = "查询企业员工账户", httpMethod = "GET")
    @PostMapping("/queryCompnayPersonnelAccount")
    public DataResult<AccountVO> queryCompnayPersonnelAccount(String userId) {
        return accountService.queryCompnayPersonnelAccount(userId);
    }
    
    @ApiOperation(value = "更新企业员工账户", notes = "更新企业员工账户", httpMethod = "POST")
    @PostMapping("/updateCompnayPersonnelAccount")
    public Result updateCompnayPersonnelAccount(@RequestBody AccountVO user) {
        return accountService.updateCompnayPersonnelAccount(user);
    }
    
    @ApiOperation(value = "查询企业员工列表", notes = "查询企业员工列表", httpMethod = "POST")
    @PostMapping("/queryCompnayPersonnelAccountByPageQuery")
    public PageResult<AccountVO> queryCompnayPersonnelAccountByPageQuery(@RequestBody PageQuery pageQuery) {
        return accountService.queryCompnayPersonnelAccountByPageQuery(pageQuery);
    }
    
    @ApiOperation(value = "删除企业员工账号", notes = "删除企业员工账号", httpMethod = "POST")
    @PostMapping("/deleteCompnayPersonnelAccountById")
    public Result deleteCompnayPersonnelAccountById(String userId) {
        return accountService.deleteCompnayPersonnelAccountById(userId);
    }
    
    @ApiOperation(value = "绑定公司", notes = "绑定公司", httpMethod = "POST")
    @PostMapping("/bindCompnay")
    public Result bindCompnay(@RequestBody BindCompanyVO bindCompanyVO) {
        return accountService.bindCompnay(bindCompanyVO);
    }
    
    /**
     * 更新用户信息
     *
     * @param user 用户信息
     * @return Result
     */
    @ApiOperation(value = "更新账户信息")
    @PostMapping("/updateUser")
    public Result updateUser(@RequestBody AccountVO user) {
        return accountService.update(user);
    }

    /**
     * 根据用户Id查询用户信息
     * @param userId 用户Id
     * @return DataResult
     */
    @ApiOperation(value = "根据用户Id查询用户信息")
    @GetMapping("/queryUserByUserId")
    public DataResult<AccountVO> queryUserByUserId(String userId){
        return accountService.queryByUserId(userId);
    }

    /**
     * 根据用户手机号查询用户信息
     * @param phone 手机号
     * @return DataResult
     */
    @ApiOperation(value = "根据用户手机号查询用户信息")
    @GetMapping("/queryUserByPhone")
    public DataResult<AccountVO> queryUserByPhone(String phone){
        return accountService.queryAccountByPhone(phone);
    }

    /**
     * 根据用户Id删除用户
     *
     * @param userId 用户Id
     * @return Result
     */

    @ApiOperation(value = "根据用户Id删除用户")
    @GetMapping("/deleteUserByUserId")
    public Result deleteUserByUserId(String userId) {
        return accountService.delete(userId);
    }

    /**
     * 根据服务商Id、用户姓名、手机号码、启用状态 分页查询账号
     *
     * @param companyId 服务商Id
     * @param userName  用户姓名
     * @param phone     手机号码
     * @param status    启用状态
     * @param current   要查询页数
     * @param size      一页的行数
     * @return PageResult
     */
    @ApiOperation(value = "根据服务商Id、用户姓名、手机号码、启用状态 分页查询账号", notes = "服务商Id选填，启用：status=0，禁用：status=1，全部：status为其他数字")
    @GetMapping("/queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus")
    public PageResult queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus(String companyId, String userName, String phone, @RequestParam Integer status, @RequestParam Long current, @RequestParam Integer size) {
        return accountService.queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus(companyId, userName, phone, status, current, size);

    }

    /**
     * 批量启用/禁用账号
     *
     * @param userIds 用户Id数组
     * @param status  启用状态
     * @return Result
     */
    @ApiOperation(value = "批量启用/禁用账号", notes = "启用：status=0，禁用：status=1")
    @PostMapping("/batchChangeStatusOfUser")
    public Result batchChangeStatusOfUser(@RequestBody String[] userIds, @RequestParam Short status) {
        return accountService.batchChangeStatusOfUser(userIds, status);
    }
    
    /**
     * 通过session查询用户
     */
    @RequestMapping("/queryUserBySession")
    @ApiOperation(value = "通过session查询用户", notes = "通过session查询用户", httpMethod = "POST")
    public DataResult<Object> queryUserBySession() {
    	return accountService.queryUserBySession();
    }
    
    /**
     * 保存微信信息
     */
    @RequestMapping("/saveWxInfo")
    @ApiOperation(value = "保存微信信息", notes = "保存微信信息", httpMethod = "POST")
    public Result saveWxInfo(@RequestBody AccountVO accountVO) {
    	return accountService.saveWxInfo(accountVO);
    }
}
