package com.hp.user.service.impl;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.apache.commons.lang3.StringUtils;
import org.apache.dubbo.common.utils.CollectionUtils;
import org.apache.dubbo.config.annotation.Service;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.hp.user.client.entity.AccountVO;
import com.hp.user.client.entity.BackstageAccountVO;
import com.hp.user.client.entity.BindCompanyVO;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.ElectricianVO;
import com.hp.user.client.entity.FuzzyQuery;
import com.hp.user.client.entity.PageQuery;
import com.hp.user.client.entity.PageResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.entity.ServiceProviderAccountVO;
import com.hp.user.client.service.AccountService;
import com.hp.user.client.service.ElectricianService;
import com.hp.user.client.service.MessageService;
import com.hp.user.service.constants.UserConstants;
import com.hp.user.service.dao.AccountMapper;
import com.hp.user.service.dao.BackstageAccountMapper;
import com.hp.user.service.dao.CustomerCompanyMapper;
import com.hp.user.service.dao.ServiceProviderAccountMapper;
import com.hp.user.service.entity.Account;
import com.hp.user.service.entity.BackstageAccount;
import com.hp.user.service.entity.ServiceProviderAccount;
import com.hp.user.service.redis.RedisOperation;
import com.hp.user.service.utils.WeixinSignUtil;

import redis.clients.jedis.Jedis;

/**
 * <p>
 * 用户信息表 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
@Service
public class AccountServiceImpl implements AccountService {
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	
    @Autowired
    private MessageService messageService;
    
    @Autowired
    private HttpServletRequest request;

    @Autowired
    private AccountMapper accountMapper;
    
    @Autowired
    private ElectricianService electricianService;
    @Autowired
    private BackstageAccountMapper backstageAccountMapper;
    @Autowired
    private ServiceProviderAccountMapper serviceProviderAccountMapper;
    @Autowired
    private CustomerCompanyMapper customerCompanyMapper;

    @Override
    public DataResult<String> login(String phone, String verificationCode) {
    	DataResult<String> result = new DataResult<String>();
    	Jedis jedis = null;
        try {
            //需要判断phone是否存在
            DataResult<Account> checkPhoneResult = checkPhone(phone);
            Account account = checkPhoneResult.getData();
            HttpSession session = request.getSession();
            if(null != account) {
            	String code = messageService.getVerificationCode(phone);
                if (StringUtils.equals(verificationCode, code)||"123456".equals(verificationCode)) {
                    //登陆成功
                	messageService.deleteVerificationCode(phone);
                	String sessionId = session.getId();
                	account.setWxOpenId(null);
                	jedis = RedisOperation.getRedis();
          		  	String key = UserConstants.SESSION_PRIFX+sessionId;
          		  	jedis.setex(key, UserConstants.EXPIRE_SECONDS, JSONObject.toJSONString(account));
          		  	result.setData(account.getUserId());
                } else {
                    //登陆失败
                    //返回错误信息
                	result.setCode("-1");
                	result.setMessage("验证码错误！");
                }
            }else {
            	result.setCode("-1");
            	result.setMessage("手机号码未注册！");
            }
        } catch (Exception e) {
        	logger.error("login have error={}",e);
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }finally {
        	if(null != jedis) {
        		jedis.close();
        	}
        }
        return result;
    }

    @Override
    public DataResult<Account> checkPhone(String phone) {
    	DataResult<Account> result = new DataResult<Account>();
        //不存在为true
        try {

            QueryWrapper<Account> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("phone", phone);
            queryWrapper.eq("sys_deleted", 0);
            Account account = accountMapper.selectOne(queryWrapper);
            if (null != account) {
                //表示手机以及存在，需要返回错误
                result.setCode("-1");
            	result.setMessage("手机号已经存在");
            	result.setData(account);
            }
        } catch (Exception e) {
        	logger.error("checkPhone have error={}",e);
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;

    }

    @Override
    public DataResult<String> register(AccountVO accountVo) {
    	DataResult<String> result = new DataResult<String>();
        try {
//        	Result checkPhoneResult = checkPhone(accountVo.getPhone());
//            if (null == checkPhoneResult.getMessage()) {
            Account account = new Account();
            String companyId = account.getCompanyId();
            Long id = IdWorker.getId();
            if(null != companyId) {
            	ServiceProviderAccount serviceProviderAccount = new ServiceProviderAccount();
            	BeanUtils.copyProperties(accountVo, serviceProviderAccount);
            	serviceProviderAccount.setUserId(id.toString());
            	serviceProviderAccountMapper.insert(serviceProviderAccount);
            }else {
            	BackstageAccount backstageAccount = new BackstageAccount();
            	BeanUtils.copyProperties(accountVo, backstageAccount);
            	backstageAccount.setUserId(id.toString());
            	backstageAccountMapper.insert(backstageAccount);
            }
//            }else {
//            	result.setCode("-1");
//            	result.setMessage(checkPhoneResult.getMessage());
//            }
        } catch (Exception e) {
        	logger.error("register have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
        }
        return result;
    }

    @Override
    public void bindWx(String userIdStr, String wxNumber) {
        try {
			Account account = new Account();
			account.setUserId(userIdStr);
			account.setWxNumber(wxNumber);
			account.setWxNumber(wxNumber);
			accountMapper.updateById(account);
		}catch(Exception e) {
			logger.error("bindWx have error={}",e);
//			result.setCode("-1");
//        	result.setMessage("系统出现问题");
		}
		
	}

	@Override
	public DataResult<AccountVO> wxAuthorization(AccountVO account,String wxCode) {
		DataResult<AccountVO> result = new DataResult<AccountVO>();
		JSONObject data = null;
		Jedis jedis = null;
		try {
	        data = WeixinSignUtil.getCode2Session(wxCode);
	        String errmsg = data.getString("errmsg");
	        if(null != errmsg) {
	        	result.setCode("-1");
	        	result.setCode(errmsg);
	        	return result;
	        }
	        String openid = data.getString("openid");
	        QueryWrapper<Account> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("wx_open_id", openid);
			Account findAccount = accountMapper.selectOne(queryWrapper);
			
			if(null == findAccount) {
				account = new AccountVO();
				String session = data.getString("session_key");
				account.setSession(session);
				account.setWxOpenId(openid);
				result.setCode("6000");
	        	result.setMessage("微信需要绑定");
	        	result.setData(account);
			}else {
				HttpSession httpSession = request.getSession();
				String sessionId = httpSession.getId();
				findAccount.setWxOpenId(null);
            	jedis = RedisOperation.getRedis();
      		  	String key = UserConstants.SESSION_PRIFX+sessionId;
      		  	jedis.setex(key, UserConstants.EXPIRE_SECONDS, JSONObject.toJSONString(account));
				if(null != account) {
					//表示需要更新微信信息
					findAccount.setWxName(account.getWxName());
					findAccount.setWxPortrait(account.getWxPortrait());
					accountMapper.updateById(findAccount);
				}
				account = new AccountVO();
				BeanUtils.copyProperties(findAccount, account);
				result.setData(account);
			}
	        
		}catch(Exception e) {
			logger.error("wxAuthorization have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}finally {
			if(null != jedis) {
				jedis.close();
			}
		}
		return result;
		
	}

	@Override
	public DataResult<AccountVO> wxRegister(AccountVO accountVO, String verificationCode) {
		DataResult<AccountVO> result = new DataResult<AccountVO>();
		try {
			if(!StringUtils.isBlank(accountVO.getPhone())) {
				DataResult<Account> checkPhone = checkPhone(accountVO.getPhone());
				Account account = checkPhone.getData();
				if(null == checkPhone.getMessage() || StringUtils.isBlank(account.getWxOpenId())) {
//					if(StringUtils.isBlank(accountVO.getWxNumber())) {
//						result.setCode("-1");
//			        	result.setMessage("微信号不能为空！");
//						return result;
//					}
					String openid = accountVO.getWxOpenId();
					if(StringUtils.isBlank(openid)) {
						result.setCode("-1");
			        	result.setMessage("微信的openId不能为空！");
						return result;
					}
					 QueryWrapper<Account> queryWrapper = new QueryWrapper<>();
					queryWrapper.eq("wx_open_id", openid);
					Integer count = accountMapper.selectCount(queryWrapper);
					if(count > 0) {
						result.setCode("-1");
			        	result.setMessage("微信的opeanId已经绑定过！");
						return result;
					}
					String code = messageService.getVerificationCode(accountVO.getPhone());
					if(StringUtils.equals(verificationCode, code)) {
						messageService.deleteVerificationCode(accountVO.getPhone());
						if(null == account) {
							account = new Account();
							Long id = IdWorker.getId();
							
							BeanUtils.copyProperties(accountVO, account);
							account.setUserId(id.toString());
							accountMapper.insert(account);
							accountVO.setUserId(id.toString());
						}else {
//							String companyId = account.getCompanyId();
//							if(!StringUtils.isBlank(companyId)) {
//								result.setCode("6001");
//					        	result.setMessage("需要确定绑定公司！");
//					        	return result;
//							}
							accountVO.setUserId(account.getUserId());
							String companyId = account.getCompanyId();
							BeanUtils.copyProperties(accountVO, account);
							accountMapper.updateById(account);
							accountVO.setCompanyId(companyId);
						}
						result.setData(accountVO);
					}else {
						result.setCode("-1");
			        	result.setMessage("验证码不正确！");
						return result;
					}
				}else {
					result.setCode("-1");
		        	result.setMessage(checkPhone.getMessage());
					return result;
				}
			}else {
				result.setCode("-1");
	        	result.setMessage("手机号不能为空！");
				return result;
			}
		}catch(Exception e) {
			logger.error("wxRegister have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
		}
		return result;
	}

    @Override
    public Result insert(AccountVO accountVO) {
        Result result = new Result();
        try {
            String companyId = accountVO.getCompanyId();
            Long id = IdWorker.getId();
            String phone = accountVO.getPhone();
            if(null != companyId) {
            	QueryWrapper<ServiceProviderAccount> queryWrapper = new QueryWrapper<ServiceProviderAccount>();
            	queryWrapper.eq("phone", phone);
            	ServiceProviderAccount serviceProviderAccount = serviceProviderAccountMapper.selectOne(queryWrapper);
            	if(null != serviceProviderAccount) {
            		result.setCode("-1");
                	result.setMessage("手机号已经存在！");
            		return result;
            	}
            	serviceProviderAccount = new ServiceProviderAccount();
            	BeanUtils.copyProperties(accountVO, serviceProviderAccount);
            	serviceProviderAccount.setUserId(id.toString());
            	serviceProviderAccountMapper.insert(serviceProviderAccount);
            }else {
            	QueryWrapper<BackstageAccount> queryWrapper = new QueryWrapper<BackstageAccount>();
            	queryWrapper.eq("phone", phone);
            	BackstageAccount backstageAccount = backstageAccountMapper.selectOne(queryWrapper);
            	if(null != backstageAccount) {
            		result.setCode("-1");
                	result.setMessage("手机号已经存在！");
            		return result;
            	}
            	backstageAccount = new BackstageAccount();
            	BeanUtils.copyProperties(accountVO, backstageAccount);
            	backstageAccount.setUserId(id.toString());
            	backstageAccountMapper.insert(backstageAccount);
            }
        } catch (Exception e) {
        	logger.error("insert have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
        }
        return result;
    }

    @Override
    public DataResult<AccountVO> queryByUserId(String userId) {
        AccountVO accountVO = new AccountVO();
        DataResult<AccountVO> result = new DataResult<>();
        try{
//            Account temp = accountMapper.selectById(userId);
//            QueryWrapper<> queryWrapper = new QueryWrapper();
            Account account = accountMapper.queryUserInfoAndCompanyInfo(Long.parseLong(userId));
            // 这个已经被删除
            if (account == null){
                result.setCode("-1");
                result.setMessage("账号不存在/已删除");
                return result;
            }
            else {
//            	account.setWxOpenId(null);
                BeanUtils.copyProperties(account, accountVO);
                result.setData(accountVO);
            }
        }catch(Exception e){
        	logger.error("insert have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
        }
        return result;
    }

    @Override
    public Result delete(String userId) {
        Account temp;
        int flag = 0;
        Result result = new Result();
        try {
            temp = accountMapper.selectById(userId);
            if (temp == null) {
                result.setCode("-1");
                result.setMessage("未查找到此账号");
                return result;
            }
            temp.setSysDeleted((short) 1);
            flag = accountMapper.updateById(temp);
        } catch (Exception e) {
        	logger.error("insert have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
        }
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("删除失败");
        }
        return result;
    }

    @Override
    public Result update(AccountVO account) {
        Result result = new Result();
        Account temp = new Account();
        int flag = 0;
        try {
            BeanUtils.copyProperties(account, temp);
            flag = accountMapper.updateById(temp);
        } catch (Exception e) {
        	logger.error("insert have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
        }
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("更新失败");
        }
        return result;
    }

    @Override
    public PageResult queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus(String companyId, String userName, String phone, Integer status, Long current, Integer size) {
        PageResult result = new PageResult<>();
        
        try {
            
            
            if (companyId != null) {
            	IPage<ServiceProviderAccount> page = new Page<>(current, size);
                QueryWrapper<ServiceProviderAccount> wrapper = new QueryWrapper<>();
                wrapper.eq("company_id", companyId);
                wrapper.orderByDesc("sys_create_time");
                if (userName != null) wrapper.like("user_name", userName);
                if (phone != null) wrapper.like("phone", phone);
                if (status == 0 || status == 1) wrapper.eq("status", status);
                serviceProviderAccountMapper.selectPage(page, wrapper);
                List<ServiceProviderAccount> accounts = page.getRecords();
                List<ServiceProviderAccountVO> accountVOs = new ArrayList<>();
                ServiceProviderAccountVO temp;
                for (ServiceProviderAccount account : accounts) {
                    temp = new ServiceProviderAccountVO();
                    BeanUtils.copyProperties(account, temp);
                    accountVOs.add(temp);
                }
                result.setCode("0");
                result.setDataList(accountVOs);
                result.setTotal(page.getTotal());
                result.setCurrent(current);
                result.setSize(size);
            }else {
            	IPage<BackstageAccount> page = new Page<>(current, size);
                QueryWrapper<BackstageAccount> wrapper = new QueryWrapper<>();
                wrapper.orderByDesc("sys_create_time");
                if (userName != null) wrapper.like("user_name", userName);
                if (phone != null) wrapper.like("phone", phone);
                if (status == 0 || status == 1) wrapper.eq("status", status);
                backstageAccountMapper.selectPage(page, wrapper);
                List<BackstageAccount> accounts = page.getRecords();
                List<BackstageAccountVO> accountVOs = new ArrayList<>();
                BackstageAccountVO temp;
                for (BackstageAccount account : accounts) {
                    temp = new BackstageAccountVO();
                    BeanUtils.copyProperties(account, temp);
                    accountVOs.add(temp);
                }
                result.setCode("0");
                result.setDataList(accountVOs);
                result.setTotal(page.getTotal());
                result.setCurrent(current);
                result.setSize(size);
            }
        } catch (Exception e) {
        	logger.error("insert have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
        }
        return result;
    }

    @Override
    public Result batchChangeStatusOfUser(String[] userIds, Short status) {
        Account account;
        Result result = new Result();
        int flag = 0;
        try {
            for (String userId : userIds) {
                account = accountMapper.selectById(userId);
                if (account == null) {
                    result.setCode("-1");
                    result.setMessage("账号Id为 " + account.getUserId() + " 的账号不存在");
                    return result;
                }
                account.setStatus(status);
                flag = accountMapper.updateById(account);
            }
        } catch (Exception e) {
        	logger.error("insert have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
        }
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
        	
            result.setCode("-1");
            result.setMessage("更新失败");
        }
        return result;
    }

    @Override
    public DataResult<AccountVO> queryAccountByPhone(String phone) {
        DataResult<AccountVO> result = new DataResult<>();
        QueryWrapper<Account> wrapper = new QueryWrapper<>();
        try {
            wrapper.eq("phone", phone);
            Account account = accountMapper.selectOne(wrapper);
            if (account == null) {
                result.setCode("-1");
                result.setMessage("未找到此手机号对应的用户");
            } else {
                AccountVO temp = new AccountVO();
                BeanUtils.copyProperties(account, temp);
                result.setCode("0");
                result.setData(temp);
            }
        } catch (Exception e) {
        	logger.error("insert have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
        }
        return result;
    }

	@Override
	public DataResult<Object> queryUserBySession() {
		DataResult<Object> result = new DataResult<Object>();
		Jedis jedis = null;
		try {
			HttpSession session = request.getSession();
			String sessionId = session.getId();
			
			String value = null;
//			AccountVO accountVO = null;
			JSONObject object = null;
			if(!StringUtils.isBlank(sessionId)) {
				jedis = RedisOperation.getRedis();
				String key = UserConstants.SESSION_PRIFX+sessionId;
				value = jedis.get(key);
				if(null != value) {
					object = JSONObject.parseObject(value);
				}
//				accountVO = JSONObject.parseObject(value, AccountVO.class);
				
			}
			result.setData(object);
//			String userId = ;
//			session.
		}catch(Exception e) {
			logger.error("insert have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
		}finally {
			if(null != jedis) {
				jedis.close();
			}
		}
		return result;
	}

	@Override
	public DataResult<ElectricianVO> appLogin(String phone, String verificationCode, String cid) {
		DataResult<ElectricianVO> result = new DataResult<ElectricianVO>();
		Jedis jedis = null;
		try {
			result = electricianService.electricianLogin(phone, verificationCode, cid);
//			DataResult<Account> checkPhoneResult = checkPhone(phone);
//            Account account = checkPhoneResult.getData();
//            HttpSession session = request.getSession();
//            if(null != account) {
//            	String code = messageService.getVerificationCode(phone);
//            	String userId = account.getUserId();
//            	DataResult<ElectricianVO> electricianResult = electricianService.queryElectricianByUserId(userId);
//            	ElectricianVO electrician = electricianResult.getData();
//            	if(null != electrician) {
//            		result.setData(electrician.getElectricianId());
//            		if (StringUtils.equals(verificationCode, code) || "123456".equals(verificationCode)) {
//                        //登陆成功
//                    	messageService.deleteVerificationCode(phone);
//                    	Result updateResult = electricianService.updateElectricianCid(electrician.getElectricianId(), cid);
//                    	if(updateResult.getCode().equals("-1")) {
//                    		result.setCode("-1");
//                    		result.setMessage(updateResult.getMessage());
//                    		return result;
//                    	}
//                    	String sessionId = session.getId();
//                    	account.setWxOpenId(null);
//                    	jedis = RedisOperation.getRedis();
//              		  	String key = UserConstants.SESSION_PRIFX+sessionId;
//              		  	jedis.setex(key, UserConstants.EXPIRE_SECONDS, JSONObject.toJSONString(account));
//                    } else {
//                        //登陆失败
//                        //返回错误信息
//                    	result.setCode("-1");
//                    	result.setMessage("验证码错误！");
//                    }
//            	}else {
//            		result.setCode("-1");
//                	result.setMessage("该账号为绑定电工！");
//            	}
//                
//            }else {
//            	result.setCode("-1");
//            	result.setMessage("手机号码未注册！");
//            }
			
		}catch(Exception e) {
			logger.error("appLogin have error={}",e);
//			e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
		}finally {
			if(null != jedis) {
				jedis.close();
			}
		}
		return result;
	}

	@Override
	public Result saveWxInfo(AccountVO accountVO) {
		Result result = new Result();
		try {
			Account account = new Account();
			BeanUtils.copyProperties(accountVO, account);
			if(StringUtils.isBlank(account.getUserId())) {
				result.setCode("-1");
	        	result.setMessage("用户id不能为空！");
			}else {
				accountMapper.updateById(account);
			}
			
		}catch(Exception e) {
			logger.error("saveWxInfo have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
		return result;
	}

	@Override
	public DataResult<String> serviceProviderLogin(String phone, String verificationCode) {
		DataResult<String> result = new DataResult<String>();
		Jedis jedis = null;
		try {
			//需要判断phone是否存在
			QueryWrapper<ServiceProviderAccount> queryWrapper = new QueryWrapper<ServiceProviderAccount>();
        	queryWrapper.eq("phone", phone);
        	ServiceProviderAccount serviceProviderAccount = serviceProviderAccountMapper.selectOne(queryWrapper);
            HttpSession session = request.getSession();
            if(null != serviceProviderAccount) {
            	String code = messageService.getVerificationCode(phone);
                if (StringUtils.equals(verificationCode, code)||"123456".equals(verificationCode)) {
                    //登陆成功
                	messageService.deleteVerificationCode(phone);
                	String sessionId = session.getId();
                	jedis = RedisOperation.getRedis();
          		  	String key = UserConstants.SESSION_PRIFX+sessionId;
          		  	jedis.setex(key, UserConstants.EXPIRE_SECONDS, JSONObject.toJSONString(serviceProviderAccount));
          		  	result.setData(serviceProviderAccount.getUserId());
                } else {
                    //登陆失败
                    //返回错误信息
                	result.setCode("-1");
                	result.setMessage("验证码错误！");
                }
            }else {
            	result.setCode("-1");
            	result.setMessage("手机号码未注册！");
            }
		}catch(Exception e) {
			logger.error("serviceProviderLogin have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}finally {
			if(null != jedis) {
				jedis.close();
			}
		}
		return result;
	}

	@Override
	public DataResult<String> backstageLogin(String phone, String verificationCode) {
		DataResult<String> result = new DataResult<String>();
		Jedis jedis = null;
		try {
			//需要判断phone是否存在
			QueryWrapper<BackstageAccount> queryWrapper = new QueryWrapper<BackstageAccount>();
        	queryWrapper.eq("phone", phone);
        	BackstageAccount backstageAccount = backstageAccountMapper.selectOne(queryWrapper);
            HttpSession session = request.getSession();
            if(null != backstageAccount) {
            	String code = messageService.getVerificationCode(phone);
                if (StringUtils.equals(verificationCode, code)||"123456".equals(verificationCode)) {
                    //登陆成功
                	messageService.deleteVerificationCode(phone);
                	String sessionId = session.getId();
                	jedis = RedisOperation.getRedis();
          		  	String key = UserConstants.SESSION_PRIFX+sessionId;
          		  	jedis.setex(key, UserConstants.EXPIRE_SECONDS, JSONObject.toJSONString(backstageAccount));
          		  	result.setData(backstageAccount.getUserId());
                } else {
                    //登陆失败
                    //返回错误信息
                	result.setCode("-1");
                	result.setMessage("验证码错误！");
                }
            }else {
            	result.setCode("-1");
            	result.setMessage("手机号码未注册！");
            }
		}catch(Exception e) {
			logger.error("backstageLogin have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}finally {
			if(null != jedis) {
				jedis.close();
			}
		}
		return result;
	}

	@Override
	public Result addCompnayPersonnelAccount(AccountVO accountVO) {
		Result result = new Result();
        try {
            String companyId = accountVO.getCompanyId();
            String phone = accountVO.getPhone();
            if(StringUtils.isNotBlank(companyId)) {
            	QueryWrapper<Account> queryWrapper = new QueryWrapper<Account>();
            	queryWrapper.eq("sys_deleted", 0);
            	queryWrapper.eq("phone", phone);
            	Account account = accountMapper.selectOne(queryWrapper);
            	if(null != account) {
            		if(StringUtils.isNotBlank(account.getCompanyId())) {
            			result.setCode("-1");
                    	result.setMessage("该手机号已经绑定公司！");
                		return result;
            		}
            		//说明手机号未绑定公司需要
            		//需要确定是否绑定该公司
            		result.setCode("2");
                	result.setMessage("需要通过手机验证码进行绑定");
            		return result;
            	}
            	account = new Account();
            	BeanUtils.copyProperties(accountVO, account);
            	accountMapper.insert(account);
            }else {
            	result.setCode("-1");
            	result.setMessage("公司ID不能为空！");
            }
        } catch (Exception e) {
        	logger.error("addCompnayPersonnelAccount have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
        }
        return result;
	}

	@Override
	public Result updateCompnayPersonnelAccount(AccountVO accountVO) {
		Result result = new Result();
		try {
//			Account account = new Account();
//			account.setUserId(accountVO.getUserId());
//			account.setUserName(accountVO.getUserName());
//			account.set
//			accountMapper.updateById(account);
		}catch(Exception e) {
			logger.error("updateCompnayPersonnelAccount have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
		}
		return result;
	}

	@Override
	public PageResult<AccountVO> queryCompnayPersonnelAccountByPageQuery(PageQuery query) {
		PageResult<AccountVO> result = new PageResult<AccountVO>();
		try {
			Integer page = query.getPage();
			Integer count = query.getSize();
			if(page == null || page == 0) {
				return result;
			}
			QueryWrapper<Account> queryWrapper = new QueryWrapper<Account>();
			List<FuzzyQuery> fuzzyList = query.getFuzzyList();
			if(CollectionUtils.isNotEmpty(fuzzyList)) {
				for(FuzzyQuery<?> fuzzy : fuzzyList) {
					queryWrapper.like(fuzzy.getColumn(), fuzzy.getValue());
					
				}
			}
			List<Account> list = null;
			Long total = null;
			if(page == -1) {
				queryWrapper.orderByDesc("sys_create_time");
				list = accountMapper.selectList(queryWrapper);
			}else {
				queryWrapper.orderByDesc("sys_create_time");
				Page<Account> accountPage = accountMapper.selectPage(new Page<>(page,count), queryWrapper);
				list = accountPage.getRecords();
				total = accountPage.getTotal();
			}
			
			List<AccountVO> newList = new ArrayList<>();
			if(CollectionUtils.isNotEmpty(list)) {
				AccountVO accountVO;
				for(Account account : list) {
					accountVO = new AccountVO();
					BeanUtils.copyProperties(account, accountVO);
					newList.add(accountVO);
				}
			}
			result.setTotal(total);
			result.setDataList(newList);
		}catch(Exception e) {
			logger.error("queryCompnayPersonnelAccountByPageQuery have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
		}
		return result;
	}

	@Override
	public Result deleteCompnayPersonnelAccountById(String userId) {
		Result result = new Result();
		try {
			Account account = new Account();
			account.setUserId(userId);
			account.setSysDeleted((short)1);
			accountMapper.updateById(account);
		}catch(Exception e) {
			logger.error("deleteCompnayPersonnelAccountByPageQuery have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
		}
		return result;
	}

	@Override
	public DataResult<AccountVO> queryCompnayPersonnelAccount(String userId) {
		DataResult<AccountVO> result = new DataResult<AccountVO>();
		try {
			Account account = accountMapper.selectById(userId);
			if(0 == account.getSysDeleted()) {
				AccountVO accountVO = new AccountVO();
				BeanUtils.copyProperties(account, accountVO);
				result.setData(accountVO);
			}
		}catch(Exception e) {
			logger.error("deleteCompnayPersonnelAccountByPageQuery have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
		}
		return result;
	}

	@Override
	public Result bindCompnay(BindCompanyVO bindCompanyVO) {
		Result result = new Result();
		Jedis jedis = null;
		try {
			String phone = bindCompanyVO.getPhone();
			String companyId = bindCompanyVO.getCompanyId();
			if(StringUtils.isBlank(companyId)) {
				result.setCode("-1");
            	result.setMessage("公司id不能为空！");
            	return result;
			}
        	String findCode = messageService.getVerificationCode(phone);
        	String code = bindCompanyVO.getCode();
            if (StringUtils.equals(findCode, code)) {
                //验证成功
            	messageService.deleteVerificationCode(phone);
            } else {
                //登陆失败
                //返回错误信息
            	result.setCode("-1");
            	result.setMessage("验证码错误！");
            	return result;
            }
			UpdateWrapper<Account> updateWrapper = new UpdateWrapper<Account>();
			updateWrapper.eq("phone", phone);
			Account account = new Account();
			account.setCompanyId(companyId);
			account.setUserName(bindCompanyVO.getUserName());
			accountMapper.update(account, updateWrapper);
		}catch(Exception e) {
			logger.error("bindCompnay have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统内部错误！");
		}finally {
			if(null != jedis) {
				jedis.close();
			}
		}
		return result;
	}
	
	
	
}
