package com.hp.user.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.hp.user.client.entity.AuditVO;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.AuditService;
import com.hp.user.service.constants.UserConstants;
import com.hp.user.service.dao.AuditMapper;
import com.hp.user.service.entity.Audit;
import com.hp.user.service.redis.RedisOperation;

import redis.clients.jedis.Jedis;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 审核记录 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-29
 */
@Service
public class AuditServiceImpl implements AuditService {
	
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private AuditMapper auditMapper;
    
    @Autowired
    private HttpServletRequest request;
    @Override
    public Result insert(AuditVO audit) {
        Audit temp = new Audit();
        Result result = new Result();
        int flag=0;
        try{
            BeanUtils.copyProperties(audit,temp);
            flag = auditMapper.insert(temp);
         // 判断数据库操作是否成功
            if(SqlHelper.retBool(flag)){
                result.setCode("0");
            } else {
                result.setCode("-1");
                result.setMessage("添加失败");
            }
        }catch (Exception e) {
        	logger.error("insert have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
        }
        
        return result;
    }

    @Override
    public Result update(AuditVO audit) {
        Result result = new Result();
        Audit temp = new Audit();
        int flag = 0;
        Jedis jedis = null;
        try {
            BeanUtils.copyProperties(audit, temp);
            HttpSession session = request.getSession();
            String sessionId = session.getId();
            String key = UserConstants.SESSION_PRIFX+sessionId;
            jedis = RedisOperation.getRedis();
            String accountJSONString = jedis.get(key);
            if(StringUtils.isNotBlank(accountJSONString)) {
            	JSONObject account = JSONObject.parseObject(accountJSONString);
            	temp.setCheckName(account.getString("userName"));
            }
            flag = auditMapper.updateById(temp);
            if (SqlHelper.retBool(flag)) {
                result.setCode("0");
            } else {
                result.setCode("-1");
                result.setMessage("更新失败");
            }
        } catch (Exception e) {
        	logger.error("update have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
        }
        
        return result;
    }

    @Override
    public DataResult<AuditVO> queryAuditByAuditId(String auditId) {
        AuditVO auditVO = new AuditVO();
        DataResult<AuditVO> result= new DataResult<>();
        try{
            Audit temp = auditMapper.selectById(auditId);
            if(temp == null) {
                result.setCode("-1");
                result.setMessage("审核记录不存在");
                return result;
            }else{
                BeanUtils.copyProperties(temp, auditVO);
                result.setCode("0");
                result.setData(auditVO);
            }
        }catch (Exception e) {
        	logger.error("queryAuditByAuditId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
        }
        return result;
    }
}
