package com.hp.user.service.impl;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.PostConstruct;

import org.apache.dubbo.config.annotation.Service;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.HighVoltageCabinetVO;
import com.hp.user.client.entity.HighVoltageDrawerVO;
import com.hp.user.client.entity.InspectionContentVO;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.LowVoltageCabinetVO;
import com.hp.user.client.entity.LowVoltageDrawerVO;
import com.hp.user.client.entity.Result;
import com.hp.user.client.entity.SubstationVO;
import com.hp.user.client.entity.SurveyHighVoltageSwitchCabinetVO;
import com.hp.user.client.entity.SurveySubstationVO;
import com.hp.user.client.entity.SurveyTransformerVO;
import com.hp.user.client.entity.TransformerVO;
import com.hp.user.client.entity.TreeVO;
import com.hp.user.client.service.DeviceManagerService;
import com.hp.user.service.dao.DeviceIdInfoMapper;
import com.hp.user.service.dao.HighVoltageCabinetMapper;
import com.hp.user.service.dao.HighVoltageDrawerMapper;
import com.hp.user.service.dao.InspectionContentMapper;
import com.hp.user.service.dao.LowVoltageCabinetMapper;
import com.hp.user.service.dao.LowVoltageDrawerMapper;
import com.hp.user.service.dao.SubstationMapper;
import com.hp.user.service.dao.TransformerMapper;
import com.hp.user.service.dao.TreeMapper;
import com.hp.user.service.entity.DeviceIdInfo;
import com.hp.user.service.entity.HighVoltageCabinet;
import com.hp.user.service.entity.HighVoltageDrawer;
import com.hp.user.service.entity.InspectionContent;
import com.hp.user.service.entity.LowVoltageCabinet;
import com.hp.user.service.entity.LowVoltageDrawer;
import com.hp.user.service.entity.Substation;
import com.hp.user.service.entity.SurveyHighVoltageSwitchCabinet;
import com.hp.user.service.entity.SurveySubstation;
import com.hp.user.service.entity.SurveySubstationDevice;
import com.hp.user.service.entity.SurveyTransformer;
import com.hp.user.service.entity.Transformer;
import com.hp.user.service.entity.Tree;
import com.hp.user.service.utils.OSSUtil;
import com.hp.user.service.utils.QRCodeUtils;
import com.hp.user.service.utils.SpringUtil;

@Service
public class DeviceManagerServiceImpl<T> implements DeviceManagerService {
	
	private Logger logger = LoggerFactory.getLogger(DeviceManagerServiceImpl.class);
	
	@Autowired
	private TransformerMapper transformerMapper;
	@Autowired
	private HighVoltageCabinetMapper highVoltageCabinetMapper;
	@Autowired
	private LowVoltageCabinetMapper lowVoltageCabinetMapper;
	
	@Autowired
	private HighVoltageDrawerMapper highVoltageDrawerMapper;
	
	@Autowired
	private LowVoltageDrawerMapper lowVoltageDrawerMapper;
	@Autowired
	private InspectionContentMapper inspectionContentMapper;
	
	@Autowired
	private DeviceIdInfoMapper deviceIdInfoMapper;
	
	@Autowired
	private SubstationMapper substationMapper;
	@Autowired
	private TreeMapper treeMapper;
	
	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createTransformer(TransformerVO transformerVO) {
		Result result = new Result();
		try {
			
			String name = transformerVO.getDeviceName();
			String substationId = transformerVO.getSubstationId();
			QueryWrapper<Transformer> queryWrapper = new QueryWrapper<Transformer>();
			queryWrapper.eq("device_name", name);
			queryWrapper.eq("substation_id", substationId);
			Integer count = transformerMapper.selectCount(queryWrapper);
			if(count > 0) {
				result.setCode("-1");
				result.setMessage("设备名称已存在");
				return result;
			}
			Transformer transformer = new Transformer();
			String deviceId = IdWorker.getIdStr();
			String key = deviceId +".png";
			OSSUtil.putObject(key,QRCodeUtils.getInputStream(deviceId));
			transformerVO.setOssUrl("oss://"+key);
			transformerVO.setDeviceId(deviceId);
			BeanUtils.copyProperties(transformerVO, transformer);
			transformerMapper.insert(transformer);
			DeviceIdInfo deviceIdInfo = new DeviceIdInfo();
			deviceIdInfo.setDeviceId(deviceId);
			deviceIdInfo.setQueryMethod("queryTransformerById");
			deviceIdInfo.setDeviceTypeId("1367397036808826883");
			deviceIdInfoMapper.insert(deviceIdInfo);
			Tree tree = new Tree();
			tree.setDeviceId(deviceId);
			tree.setParentId(substationId);
			tree.setDeviceName(name);
			tree.setOssUrl(transformerVO.getOssUrl());
			tree.setDeviceTypeId("1367397036808826883");		
			treeMapper.insert(tree);
		}catch(Exception e) {
			logger.error("createTransformer have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateTransformer(TransformerVO transformerVO) {
		Result result = new Result();
		try {
			Transformer transformer = new Transformer();
			
			BeanUtils.copyProperties(transformerVO, transformer);
			transformerMapper.updateById(transformer);
			String deviceId = transformer.getDeviceId();
			String substationId = transformer.getSubstationId();
			String name = transformer.getDeviceName();
			Tree tree = new Tree();
			tree.setDeviceId(deviceId);
			tree.setParentId(substationId);
			tree.setDeviceName(name);
			UpdateWrapper<Tree> updateWrapper = new UpdateWrapper<Tree>();
			updateWrapper.eq("device_id", deviceId);
			treeMapper.update(tree, updateWrapper);
		}catch(Exception e) {
			logger.error("updateTransformer have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<TransformerVO> queryTransformerBySubStationId(String subStationId) {
		ListResult<TransformerVO> result = new ListResult<TransformerVO>();
		try {
			QueryWrapper<Transformer> queryWrapper = new QueryWrapper<Transformer>();
			queryWrapper.eq("substation_id", subStationId);
			List<Transformer> list = transformerMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				TransformerVO transformerVO;
				List<TransformerVO> newList = new ArrayList<>();
				for(Transformer transformer : list) {
					transformerVO = new TransformerVO();
					BeanUtils.copyProperties(transformer, transformerVO);
					newList.add(transformerVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryTransformerBySubStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createHighVoltageCabinet(HighVoltageCabinetVO highVoltageCabinetVO) {
		Result result = new Result();
		try {
			String name = highVoltageCabinetVO.getDeviceName();
			String substationId = highVoltageCabinetVO.getSubstationId();
			QueryWrapper<HighVoltageCabinet> queryWrapper = new QueryWrapper<HighVoltageCabinet>();
			queryWrapper.eq("device_name", name);
			queryWrapper.eq("substation_id", substationId);
			Integer count = highVoltageCabinetMapper.selectCount(queryWrapper);
			if(count > 0) {
				result.setCode("-1");
				result.setMessage("设备名称已存在");
				return result;
			}
			HighVoltageCabinet highVoltageCabinet = new HighVoltageCabinet();
			String deviceId = IdWorker.getIdStr();
			String key = deviceId +".png";
			OSSUtil.putObject(key,QRCodeUtils.getInputStream(deviceId));
			highVoltageCabinetVO.setOssUrl("oss://"+key);
			highVoltageCabinetVO.setDeviceId(deviceId);
			BeanUtils.copyProperties(highVoltageCabinetVO, highVoltageCabinet);
			highVoltageCabinetMapper.insert(highVoltageCabinet);
			DeviceIdInfo deviceIdInfo = new DeviceIdInfo();
			deviceIdInfo.setDeviceId(deviceId);
			deviceIdInfo.setQueryMethod("queryHighVoltageCabinetById");
			deviceIdInfo.setDeviceTypeId("1367397037211480066");
			deviceIdInfoMapper.insert(deviceIdInfo);
			Tree tree = new Tree();
			tree.setDeviceId(deviceId);
			tree.setParentId(substationId);
			tree.setDeviceName(name);
			tree.setOssUrl(highVoltageCabinetVO.getOssUrl());
			tree.setDeviceTypeId("1367397037211480066");		
			treeMapper.insert(tree);
		}catch(Exception e) {
			logger.error("createHighVoltageCabinet have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<HighVoltageCabinetVO> queryHighVoltageCabinetBySubStationId(String subStationId) {
		ListResult<HighVoltageCabinetVO> result = new ListResult<HighVoltageCabinetVO>();
		try {
			QueryWrapper<HighVoltageCabinet> queryWrapper = new QueryWrapper<HighVoltageCabinet>();
			queryWrapper.eq("substation_id", subStationId);
			List<HighVoltageCabinet> list = highVoltageCabinetMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				HighVoltageCabinetVO highVoltageCabinetVO;
				List<HighVoltageCabinetVO> newList = new ArrayList<>();
				for(HighVoltageCabinet highVoltageCabinet : list) {
					highVoltageCabinetVO = new HighVoltageCabinetVO();
					BeanUtils.copyProperties(highVoltageCabinet, highVoltageCabinetVO);
					newList.add(highVoltageCabinetVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryHighVoltageCabinetBySubStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateHighVoltageCabinet(HighVoltageCabinetVO highVoltageCabinetVO) {
		Result result = new Result();
		try {
			HighVoltageCabinet highVoltageCabinet = new HighVoltageCabinet();
			BeanUtils.copyProperties(highVoltageCabinetVO, highVoltageCabinet);
			highVoltageCabinetMapper.updateById(highVoltageCabinet);
			String deviceId = highVoltageCabinetVO.getDeviceId();
			String substationId = highVoltageCabinetVO.getSubstationId();
			String name = highVoltageCabinetVO.getDeviceName();
			Tree tree = new Tree();
			tree.setDeviceId(deviceId);
			tree.setParentId(substationId);
			tree.setDeviceName(name);
			UpdateWrapper<Tree> updateWrapper = new UpdateWrapper<Tree>();
			updateWrapper.eq("device_id", deviceId);
//			updateWrapper.set("device_type_id", highVoltageCabinet.getDeviceTypeId());
			treeMapper.update(tree, updateWrapper);
		}catch(Exception e) {
			logger.error("updateHighVoltageCabinet have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createLowVoltageCabinet(LowVoltageCabinetVO lowVoltageCabinetVO) {
		Result result = new Result();
		try {
			
			String name = lowVoltageCabinetVO.getDeviceName();
			String substationId = lowVoltageCabinetVO.getSubstationId();
			QueryWrapper<LowVoltageCabinet> queryWrapper = new QueryWrapper<LowVoltageCabinet>();
			queryWrapper.eq("device_name", name);
			queryWrapper.eq("substation_id", substationId);
			Integer count = lowVoltageCabinetMapper.selectCount(queryWrapper);
			if(count > 0) {
				result.setCode("-1");
				result.setMessage("设备名称已存在");
				return result;
			}
			LowVoltageCabinet lowVoltageCabinet = new LowVoltageCabinet();
			String deviceId = IdWorker.getIdStr();
			String key = deviceId +".png";
			OSSUtil.putObject(key,QRCodeUtils.getInputStream(deviceId));
			lowVoltageCabinetVO.setOssUrl("oss://"+key);
			lowVoltageCabinetVO.setDeviceId(deviceId);
			BeanUtils.copyProperties(lowVoltageCabinetVO, lowVoltageCabinet);
			lowVoltageCabinetMapper.insert(lowVoltageCabinet);
			DeviceIdInfo deviceIdInfo = new DeviceIdInfo();
			deviceIdInfo.setDeviceId(deviceId);
			deviceIdInfo.setQueryMethod("queryLowVoltageCabinetById");
			deviceIdInfo.setDeviceTypeId("1367397037605744642");
			deviceIdInfoMapper.insert(deviceIdInfo);
			Tree tree = new Tree();
			tree.setDeviceId(deviceId);
			tree.setParentId(substationId);
			tree.setDeviceName(name);
			tree.setOssUrl(lowVoltageCabinetVO.getOssUrl());
			tree.setDeviceTypeId("1367397037605744642");		
			treeMapper.insert(tree);
		}catch(Exception e) {
			logger.error("createLowVoltageCabinet have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<LowVoltageCabinetVO> queryLowVoltageCabinetBySubStationId(String subStationId) {
		ListResult<LowVoltageCabinetVO> result = new ListResult<LowVoltageCabinetVO>();
		try {
			QueryWrapper<LowVoltageCabinet> queryWrapper = new QueryWrapper<LowVoltageCabinet>();
			queryWrapper.eq("substation_id", subStationId);
			List<LowVoltageCabinet> list = lowVoltageCabinetMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				LowVoltageCabinetVO lowVoltageCabinetVO;
				List<LowVoltageCabinetVO> newList = new ArrayList<>();
				for(LowVoltageCabinet lowVoltageCabinet : list) {
					lowVoltageCabinetVO = new LowVoltageCabinetVO();
					BeanUtils.copyProperties(lowVoltageCabinet, lowVoltageCabinetVO);
					newList.add(lowVoltageCabinetVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryLowVoltageCabinetBySubStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateLowVoltageCabinet(LowVoltageCabinetVO lowVoltageCabinetVO) {
		Result result = new Result();
		try {
			LowVoltageCabinet lowVoltageCabinet = new LowVoltageCabinet();
			BeanUtils.copyProperties(lowVoltageCabinetVO, lowVoltageCabinet);
			lowVoltageCabinetMapper.updateById(lowVoltageCabinet);
			String deviceId = lowVoltageCabinetVO.getDeviceId();
			String substationId = lowVoltageCabinetVO.getSubstationId();
			String name = lowVoltageCabinetVO.getDeviceName();
			Tree tree = new Tree();
			tree.setDeviceId(deviceId);
			tree.setParentId(substationId);
			tree.setDeviceName(name);
			UpdateWrapper<Tree> updateWrapper = new UpdateWrapper<Tree>();
			updateWrapper.eq("device_id", deviceId);
			treeMapper.update(tree, updateWrapper);
		}catch(Exception e) {
			logger.error("updateLowVoltageCabinet have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result createHighVoltageCabinetDrawer(HighVoltageDrawerVO highVoltageDrawerVO) {
		Result result = new Result();
		try {

			String name = highVoltageDrawerVO.getDeviceName();
			String cabinetId = highVoltageDrawerVO.getCabinetId();
			QueryWrapper<HighVoltageDrawer> queryWrapper = new QueryWrapper<HighVoltageDrawer>();
			queryWrapper.eq("device_name", name);
			queryWrapper.eq("cabinet_id", cabinetId);
			Integer count = highVoltageDrawerMapper.selectCount(queryWrapper);
			if(count > 0) {
				result.setCode("-1");
				result.setMessage("设备名称已存在");
				return result;
			}
			HighVoltageDrawer highVoltageDrawer = new HighVoltageDrawer();
			BeanUtils.copyProperties(highVoltageDrawerVO, highVoltageDrawer);
			highVoltageDrawerMapper.insert(highVoltageDrawer);
		}catch(Exception e) {
			logger.error("createHighVoltageCabinetDrawer have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateHighVoltageCabinetDrawer(HighVoltageDrawerVO highVoltageDrawerVO) {
		Result result = new Result();
		try {
			HighVoltageDrawer highVoltageDrawer = new HighVoltageDrawer();
			BeanUtils.copyProperties(highVoltageDrawerVO, highVoltageDrawer);
			highVoltageDrawerMapper.updateById(highVoltageDrawer);
		}catch(Exception e) {
			logger.error("updateHighVoltageCabinetDrawer have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result createLowVoltageCabinetDrawer(LowVoltageDrawerVO lowVoltageDrawerVO) {
		Result result = new Result();
		try {
			String name = lowVoltageDrawerVO.getDeviceName();
			String cabinetId = lowVoltageDrawerVO.getCabinetId();
			QueryWrapper<LowVoltageDrawer> queryWrapper = new QueryWrapper<LowVoltageDrawer>();
			queryWrapper.eq("device_name", name);
			queryWrapper.eq("cabinet_id", cabinetId);
			Integer count = lowVoltageDrawerMapper.selectCount(queryWrapper);
			if(count > 0) {
				result.setCode("-1");
				result.setMessage("设备名称已存在");
				return result;
			}
			LowVoltageDrawer lowVoltageDrawer = new LowVoltageDrawer();
			BeanUtils.copyProperties(lowVoltageDrawerVO, lowVoltageDrawer);
			lowVoltageDrawerMapper.insert(lowVoltageDrawer);
		}catch(Exception e) {
			logger.error("createLowVoltageCabinetDrawer have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateLowVoltageCabinetDrawer(LowVoltageDrawerVO lowVoltageDrawerVO) {
		Result result = new Result();
		try {
			LowVoltageDrawer lowVoltageDrawer = new LowVoltageDrawer();
			BeanUtils.copyProperties(lowVoltageDrawerVO, lowVoltageDrawer);
			lowVoltageDrawerMapper.updateById(lowVoltageDrawer);
		}catch(Exception e) {
			logger.error("updateLowVoltageCabinetDrawer have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<HighVoltageDrawerVO> queryHighVoltageCabinetDrawerByCabinetId(String cabinetId) {
		ListResult<HighVoltageDrawerVO> result = new ListResult<HighVoltageDrawerVO>();
		try {
			QueryWrapper<HighVoltageDrawer> queryWrapper = new QueryWrapper<HighVoltageDrawer>();
			queryWrapper.eq("cabinet_id", cabinetId);
			List<HighVoltageDrawer> list = highVoltageDrawerMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				HighVoltageDrawerVO highVoltageDrawerVO;
				List<HighVoltageDrawerVO> newList = new ArrayList<>();
				for(HighVoltageDrawer highVoltageDrawer : list) {
					highVoltageDrawerVO = new HighVoltageDrawerVO();
					BeanUtils.copyProperties(highVoltageDrawer, highVoltageDrawerVO);
					newList.add(highVoltageDrawerVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryHighVoltageCabinetDrawerByCabinetId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<LowVoltageDrawerVO> queryLowVoltageCabinetDrawerByCabinetId(String cabinetId) {
		ListResult<LowVoltageDrawerVO> result = new ListResult<LowVoltageDrawerVO>();
		try {
			QueryWrapper<LowVoltageDrawer> queryWrapper = new QueryWrapper<LowVoltageDrawer>();
			queryWrapper.eq("cabinet_id", cabinetId);
			List<LowVoltageDrawer> list = lowVoltageDrawerMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				LowVoltageDrawerVO lowVoltageDrawerVO;
				List<LowVoltageDrawerVO> newList = new ArrayList<>();
				for(LowVoltageDrawer highVoltageDrawer : list) {
					lowVoltageDrawerVO = new LowVoltageDrawerVO();
					BeanUtils.copyProperties(highVoltageDrawer, lowVoltageDrawerVO);
					newList.add(lowVoltageDrawerVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryLowVoltageCabinetDrawerByCabinetId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<LowVoltageDrawerVO> queryLowVoltageDrawerById(String Id) {
		DataResult<LowVoltageDrawerVO> result =  new DataResult<LowVoltageDrawerVO>();
		try {
			LowVoltageDrawer lowVoltageDrawer = lowVoltageDrawerMapper.selectById(Id);
			if(null != lowVoltageDrawer) {
				LowVoltageDrawerVO lowVoltageDrawerVO = new LowVoltageDrawerVO();
				BeanUtils.copyProperties(lowVoltageDrawer, lowVoltageDrawerVO);
				result.setData(lowVoltageDrawerVO);
			}
			
		}catch(Exception e) {
			logger.error("queryLowVoltageDrawerById have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<HighVoltageDrawerVO> queryHighVoltageDrawerById(String Id) {
		DataResult<HighVoltageDrawerVO> result =  new DataResult<HighVoltageDrawerVO>();
		try {
			HighVoltageDrawer highVoltageDrawer = highVoltageDrawerMapper.selectById(Id);
			if(null != highVoltageDrawer) {
				HighVoltageDrawerVO highVoltageDrawerVO = new HighVoltageDrawerVO();
				BeanUtils.copyProperties(highVoltageDrawer, highVoltageDrawerVO);
				result.setData(highVoltageDrawerVO);
			}
			
		}catch(Exception e) {
			logger.error("queryHighVoltageDrawerById have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<LowVoltageCabinetVO> queryLowVoltageCabinetById(String Id) {
		DataResult<LowVoltageCabinetVO> result =  new DataResult<LowVoltageCabinetVO>();
		try {
			LowVoltageCabinet lowVoltageCabinet = lowVoltageCabinetMapper.selectById(Id);
			if(null != lowVoltageCabinet) {
				LowVoltageCabinetVO lowVoltageCabinetVO = new LowVoltageCabinetVO();
				BeanUtils.copyProperties(lowVoltageCabinet, lowVoltageCabinetVO);
				result.setData(lowVoltageCabinetVO);
			}
			
		}catch(Exception e) {
			logger.error("queryLowVoltageCabinetById have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<HighVoltageCabinetVO> queryHighVoltageCabinetById(String Id) {
		DataResult<HighVoltageCabinetVO> result =  new DataResult<HighVoltageCabinetVO>();
		try {
			HighVoltageCabinet highVoltageCabinet = highVoltageCabinetMapper.selectById(Id);
			if(null != highVoltageCabinet) {
				HighVoltageCabinetVO highVoltageCabinetVO = new HighVoltageCabinetVO();
				BeanUtils.copyProperties(highVoltageCabinet, highVoltageCabinetVO);
				result.setData(highVoltageCabinetVO);
			}
			
		}catch(Exception e) {
			logger.error("queryHighVoltageCabinetById have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<TransformerVO> queryTransformerById(String Id) {
		DataResult<TransformerVO> result =  new DataResult<TransformerVO>();
		try {
			Transformer transformer = transformerMapper.selectById(Id);
			if(null != transformer) {
				TransformerVO transformerVO = new TransformerVO();
				BeanUtils.copyProperties(transformer, transformerVO);
				result.setData(transformerVO);
			}
			
		}catch(Exception e) {
			logger.error("queryTransformerById have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<InspectionContentVO> queryInspectionContentByTypeId(String deviceTypeId) {
		ListResult<InspectionContentVO>  result = new ListResult<InspectionContentVO>();
		try {
			QueryWrapper<InspectionContent> queryWrapper = new QueryWrapper<InspectionContent>();
			queryWrapper.eq("device_type_id", deviceTypeId);
			List<InspectionContent> list = inspectionContentMapper.queryInspectionContentListByDeviceTypeId(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				InspectionContentVO inspectionContentVO;
				List<InspectionContentVO> newList = new ArrayList<>();
				for(InspectionContent inspectionContent : list) {
					inspectionContentVO = new InspectionContentVO();
					BeanUtils.copyProperties(inspectionContent, inspectionContentVO);
					newList.add(inspectionContentVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryInspectionContentByTypeId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<InspectionContentVO> queryOtherInspectionContent() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public ListResult<InspectionContentVO> queryInspectionContentByDeviceId(String deviceId) {
		ListResult<InspectionContentVO> result = new ListResult<InspectionContentVO>();
		try {
			//先根据deviceId查询到设备类型id
			List<InspectionContent> list = inspectionContentMapper.queryContentByDeviceId(deviceId);
			if(CollectionUtils.isNotEmpty(list)) {
				InspectionContentVO inspectionContentVO;
				List<InspectionContentVO> newList = new ArrayList<>();
				for(InspectionContent inspectionContent : list) {
					inspectionContentVO = new InspectionContentVO();
					BeanUtils.copyProperties(inspectionContent, inspectionContentVO);
					newList.add(inspectionContentVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryInspectionContentByDeviceId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<Object> querydeviceInfoByDeviceId(String deviceId) {
		DataResult<Object> result = new DataResult<Object>();
		try {
			//首先需要查询出需要通过哪个方法来查询
			QueryWrapper<DeviceIdInfo> queryWrapper = new QueryWrapper<DeviceIdInfo>();
			queryWrapper.eq("device_id", deviceId);
			DeviceIdInfo deviceIdInfo = deviceIdInfoMapper.selectOne(queryWrapper);
			if(null != deviceIdInfo) {
				String methodName = deviceIdInfo.getQueryMethod();
				Object device;
				switch(methodName) {
					case "queryLowVoltageCabinetById":
						device = queryLowVoltageCabinetById(deviceId).getData();
						break;
					case "queryHighVoltageCabinetById":
						device = queryHighVoltageCabinetById(deviceId).getData();
						break;
					case "queryTransformerById":
						device = queryTransformerById(deviceId).getData();
						break;
					case "querySubstationById":
						device = querySubstationById(deviceId).getData();
						break;
					default:
						device = null;
						break;
				}
				result.setData(device);
			}
		}catch(Exception e) {
			logger.error("queryInspectionContentByDeviceId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createSubstation(SubstationVO substationVO) {
		Result result = new Result();
		try {
			
			String deviceName = substationVO.getDeviceName();
			String stationId = substationVO.getStationId();
			QueryWrapper<Substation> queryWrapper = new QueryWrapper<Substation>();
			queryWrapper.eq("device_name", deviceName);
			queryWrapper.eq("station_id", stationId);
			queryWrapper.eq("sys_status", 0);
			Integer count = substationMapper.selectCount(queryWrapper);
			if(count > 0) {
				result.setCode("-1");
				result.setMessage("配电房名称已经存在");
				return result;
			}
			Substation substation = new Substation();
			String deviceId = IdWorker.getIdStr();
			String key = deviceId +".png";
			OSSUtil.putObject(key,QRCodeUtils.getInputStream(deviceId));
			substationVO.setOssUrl("oss://"+key);
			substationVO.setDeviceId(deviceId);
			BeanUtils.copyProperties(substationVO, substation);
			substationMapper.insert(substation);
			DeviceIdInfo deviceIdInfo = new DeviceIdInfo();
			deviceIdInfo.setDeviceId(deviceId);
			deviceIdInfo.setQueryMethod("querySubstationById");
			deviceIdInfo.setDeviceTypeId("1367397038381690881");
			deviceIdInfoMapper.insert(deviceIdInfo);
			
		}catch(Exception e) {
			logger.error("createSubstation have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateSubstation(SubstationVO substationVO) {
		Result result = new Result();
		try {
			Substation substation = new Substation();
			BeanUtils.copyProperties(substationVO, substation);
			substationMapper.updateById(substation);
		}catch(Exception e) {
			logger.error("updateSubstation have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}
	
	@Override
	public ListResult<SubstationVO> querySubstationByStationId(String stationId) {
		ListResult<SubstationVO> result = new ListResult<SubstationVO>();
		try {
			
			QueryWrapper<Substation> queryWrapper = new QueryWrapper<Substation>();
			queryWrapper.eq("station_id", stationId);
			List<Substation> list = substationMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				SubstationVO substationVO;
				List<SubstationVO> newList = new ArrayList<>();
				for(Substation substation  : list) {
					substationVO = new SubstationVO();
					BeanUtils.copyProperties(substation, substationVO);
					newList.add(substationVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("querySubstationByStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<SubstationVO> querySubstationById(String id) {
		DataResult<SubstationVO> result = new DataResult<SubstationVO>();
		try {
			
			Substation substation = substationMapper.selectById(id);
			if(null != substation) {
				SubstationVO substationVO = new SubstationVO();
				BeanUtils.copyProperties(substation, substationVO);
				result.setData(substationVO);			}
		}catch(Exception e) {
			logger.error("querySubstationById have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<TreeVO> queryLowerDeviceByParentId(String parentId) {
		ListResult<TreeVO> result = new ListResult<TreeVO>();
		try {
			//先查询高压柜
			QueryWrapper<Tree> queryWrapper = new QueryWrapper<Tree>();
			queryWrapper.eq("parent_id", parentId);
			List<Tree> list = treeMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				List<TreeVO> newList = new ArrayList<>();
				TreeVO treeVO;
				for(Tree tree : list) {
					treeVO = new TreeVO();
					BeanUtils.copyProperties(tree, treeVO);
					newList.add(treeVO);
				}
				result.setDataList(newList);
			}
			
		}catch(Exception e) {
			logger.error("querySubstationLowerDevice have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}
	
}
