package com.hp.user.service.impl;

import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


import org.apache.commons.lang3.StringUtils;
import org.apache.dubbo.common.utils.CollectionUtils;
import org.apache.dubbo.config.annotation.Service;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.ElectricianCertificateVO;
import com.hp.user.client.entity.ElectricianVO;
import com.hp.user.client.entity.FuzzyQuery;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.PageQuery;
import com.hp.user.client.entity.PageResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.ElectricianService;
import com.hp.user.client.service.MessageService;
import com.hp.user.service.constants.UserConstants;
import com.hp.user.service.dao.ElectricianCertificateMapper;
import com.hp.user.service.dao.ElectricianGroupMapper;
import com.hp.user.service.dao.ElectricianMapper;
import com.hp.user.service.dao.ElectricianRoleMapper;
import com.hp.user.service.entity.Electrician;
import com.hp.user.service.entity.ElectricianCertificate;
import com.hp.user.service.entity.ElectricianRole;
import com.hp.user.service.redis.RedisOperation;
import com.hp.user.service.utils.MapUtil;

import redis.clients.jedis.Jedis;

@Service
public class ElectricianServiceImpl implements ElectricianService{
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	
	@Autowired
	private ElectricianMapper electricianMapper;
	
	@Autowired
	private ElectricianCertificateMapper certificateMapper;
	
	@Autowired
    private MessageService messageService;
	
//	@Autowired
//    private HttpServletRequest request;
	
	@Autowired
	private ElectricianGroupMapper electricianGroupMapper;
	
	@Autowired
	private ElectricianRoleMapper electricianRoleMapper;
//	@Autowired
//	private AccountService accountService;

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createElectrician(ElectricianVO electricianVO) {
		Result result = new Result();
		try {
			//创建电工的时候需要绑定一个账号
			String phone = electricianVO.getPhone();
			String name = electricianVO.getName();
			String serviceProviderId = electricianVO.getServiceProviderId();
			if(StringUtils.isBlank(phone)) {
				result.setCode("-1");
				result.setMessage("手机号不能为空！");
				return result;
			}
			if(StringUtils.isBlank(name)) {
				result.setCode("-1");
				result.setMessage("姓名能为空！");
				return result;
			}
			if(StringUtils.isBlank(serviceProviderId)) {
				result.setCode("-1");
				result.setMessage("服务商ID不能为空！");
				return result;
			}
			String tag = electricianVO.getTag();
			if(StringUtils.isBlank(tag)) {
				result.setCode("-1");
				result.setMessage("电工类型不能为空！");
				return result;
			}
			List<ElectricianCertificateVO> certificateVOList = electricianVO.getCertificateVOList();
			if(CollectionUtils.isEmpty(certificateVOList)) {
				result.setCode("-1");
				result.setMessage("电工证书不能为空！");
				return result;
			}
			Long workingStart = electricianVO.getWorkingStart();
			if(null == workingStart) {
				result.setCode("-1");
				result.setMessage("电工开始工作时间不能为空！");
				return result;
			}
			
			
//			AccountVO account = new AccountVO();
//			account.setCompanyId(serviceProviderId);
//			account.setPhone(phone);
//			account.setUserName(name);
//			DataResult<String> accountResult = accountService.register(account);
//			if(accountResult.getCode().equals("0")) {
			Electrician electrician = new Electrician();
			LocalDateTime localDate = LocalDateTime.now();
			LocalDateTime workingStartDate = LocalDateTime.ofEpochSecond(workingStart, 0, ZoneOffset.ofHours(8));
			Integer workingYears = localDate.getYear() - workingStartDate.getYear();
			BeanUtils.copyProperties(electricianVO, electrician);
			Integer workingMonths = localDate.getMonthValue() - workingStartDate.getMonthValue()+1;
			electrician.setWorkingYears(workingYears*12 + workingMonths);
			String electricianId = IdWorker.getIdStr();
			electrician.setElectricianId(electricianId);
			String userId = IdWorker.getIdStr();
			electrician.setUserId(userId);
			electricianMapper.insert(electrician);
			List<ElectricianCertificate> certificateList = new ArrayList<>();
			ElectricianCertificate electricianCertificate = null;
			for(ElectricianCertificateVO electricianCertificateVO : certificateVOList) {
				electricianCertificate = new ElectricianCertificate();
				BeanUtils.copyProperties(electricianCertificateVO, electricianCertificate);
				electricianCertificate.setElectricianId(electricianId);
				certificateList.add(electricianCertificate);
			}
			certificateMapper.batchInsert(certificateList);
			
			String[] tags = StringUtils.split(tag, ",");
			List<ElectricianRole> list = new ArrayList<>();
			ElectricianRole electricianRole;
			for(String id : tags) {
				electricianRole = new ElectricianRole();
				electricianRole.setDictionariesId(id);
				electricianRole.setElectricianId(electricianId);
				list.add(electricianRole);
			}
			electricianRoleMapper.insertBatch(list);
//			}else {
//				result.setCode("-1");
//				result.setMessage(accountResult.getMessage());
//			}
			
		}catch(Exception e) {
			logger.error("createElectrician have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
			throw e;
		}
		return result;
	}

	@Override
	public PageResult<ElectricianVO> queryElectrician(PageQuery query) {
		PageResult<ElectricianVO> result = new PageResult<ElectricianVO>();
		try {
			Integer page = query.getPage();
			Integer count = query.getSize();
			if(page == null || page == 0) {
				return result;
			}
			QueryWrapper<Electrician> queryWrapper = new QueryWrapper<Electrician>();
			List<FuzzyQuery> fuzzyList = query.getFuzzyList();
			if(CollectionUtils.isNotEmpty(fuzzyList)) {
				for(FuzzyQuery<?> fuzzy : fuzzyList) {
					if("dictionaries_id".equals(fuzzy.getColumn())) {
						queryWrapper.like(fuzzy.getColumn(), "1351073342146838531");
					}else {
						queryWrapper.like(fuzzy.getColumn(), fuzzy.getValue());
					}
					
				}
			}
			List<Electrician> list = null;
			Long total = null;
			if(page == -1) {
				queryWrapper.groupBy("c.electrician_id");
				queryWrapper.orderByDesc("c.electrician_id");
				list = electricianMapper.selectAll(queryWrapper);
			}else {
				queryWrapper.groupBy("c.electrician_id");
				Page<Electrician> electricianPage = electricianMapper.queryElectricianByQuey(new Page<>(page,count), queryWrapper);
				list = electricianPage.getRecords();
				total = electricianPage.getTotal();
			}
			
			List<ElectricianVO> newList = new ArrayList<>();
			if(CollectionUtils.isNotEmpty(list)) {
				ElectricianVO electricianVO;
				List<Long> electricianIds = new ArrayList<>();
				for(Electrician electrician : list) {
					electricianIds.add(Long.parseLong(electrician.getElectricianId()));
				}
				QueryWrapper<ElectricianCertificate> certificateQueryWrapper = new QueryWrapper<ElectricianCertificate>();
				certificateQueryWrapper.in("electrician_id", electricianIds);
				List<ElectricianCertificate> certificateList = certificateMapper.selectList(certificateQueryWrapper);
				Map<String,List<ElectricianCertificateVO>> electricianCertificateMap = new HashMap<>();
				if(CollectionUtils.isNotEmpty(certificateList)) {
					
					String electricianId;
					List<ElectricianCertificateVO> groupList;
					ElectricianCertificateVO electricianCertificateVO;
					for(ElectricianCertificate certificate : certificateList) {
						electricianId = certificate.getElectricianId();
						electricianCertificateVO = new ElectricianCertificateVO();
						BeanUtils.copyProperties(certificate, electricianCertificateVO);
						groupList = electricianCertificateMap.get(electricianId);
						if(null ==  groupList) {
							groupList = new ArrayList<>();
						}
						groupList.add(electricianCertificateVO);
						electricianCertificateMap.put(electricianId, groupList);
					}
				}
				for(Electrician electrician : list) {
					electricianVO = new ElectricianVO();
					BeanUtils.copyProperties(electrician, electricianVO);
					electricianVO.setCertificateVOList(electricianCertificateMap.get(electrician.getElectricianId()));
					newList.add(electricianVO);
				}
			}
			result.setTotal(total);
			result.setDataList(newList);
		}catch(Exception e) {
			logger.error("queryElectrician have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result updateElectrician(ElectricianVO electricianVO) {
		Result result = new Result();
		try {
			String tag = electricianVO.getTag();
			if(StringUtils.isBlank(tag)) {
				result.setCode("-1");
				result.setMessage("电工类型不能为空！");
				return result;
			}
			//需要先删除电工和证书的关系
			String electricianId = electricianVO.getElectricianId();
			QueryWrapper<ElectricianCertificate> deleteWrapper = new QueryWrapper<ElectricianCertificate>();
			deleteWrapper.eq("electrician_id", electricianId);
			certificateMapper.delete(deleteWrapper);
			
			List<ElectricianCertificateVO> certificateVOList = electricianVO.getCertificateVOList();
			if(CollectionUtils.isEmpty(certificateVOList)) {
				result.setCode("-1");
				result.setMessage("电工证书不能为空！");
				return result;
			}
			Long workingStart = electricianVO.getWorkingStart();
			if(null == workingStart) {
				result.setCode("-1");
				result.setMessage("电工开始工作时间不能为空！");
				return result;
			}
			List<ElectricianCertificate> certificateList = new ArrayList<>();
			ElectricianCertificate electricianCertificate = null;
			for(ElectricianCertificateVO electricianCertificateVO : certificateVOList) {
				electricianCertificate = new ElectricianCertificate();
				BeanUtils.copyProperties(electricianCertificateVO, electricianCertificate);
				electricianCertificate.setElectricianId(electricianId);
				certificateList.add(electricianCertificate);
			}
			certificateMapper.batchInsert(certificateList);
			LocalDateTime localDate = LocalDateTime.now();
			LocalDateTime workingStartDate = LocalDateTime.ofEpochSecond(workingStart, 0, ZoneOffset.ofHours(8));
			Integer workingYears = localDate.getYear() - workingStartDate.getYear();
			Integer workingMonths = localDate.getMonthValue() - workingStartDate.getMonthValue()+1;
			Electrician electrician = new Electrician(electricianVO.getElectricianId(),electricianVO.getName(),
					electricianVO.getDictionariesId(),electricianVO.getCertificateUrl(),electricianVO.getRemarks(),electricianVO.getStatus(),electricianVO.getServiceProviderId());
			electrician.setWorkingYears(workingYears*12 + workingMonths);
			electrician.setWorkingStart(workingStart);
			electricianMapper.updateById(electrician);
			
			String[] tags = StringUtils.split(tag, ",");
			List<ElectricianRole> list = new ArrayList<>();
			ElectricianRole electricianRole;
			for(String id : tags) {
				electricianRole = new ElectricianRole();
				electricianRole.setDictionariesId(id);
				electricianRole.setElectricianId(electricianId);
				list.add(electricianRole);
			}
			if(CollectionUtils.isNotEmpty(list)) {
				QueryWrapper<ElectricianRole> wrapper = new QueryWrapper<ElectricianRole>();
				wrapper.eq("electrician_id", electricianId);
				electricianRoleMapper.delete(wrapper);
				electricianRoleMapper.insertBatch(list);
			}
		}catch(Exception e) {
			logger.error("updateElectrician have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
			throw e;
		}
		return result;
	}

	@Override
	public DataResult<ElectricianVO> queryElectricianById(String electricianId) {
		DataResult<ElectricianVO> result = new DataResult<ElectricianVO>();
		try {
			Electrician electrician = electricianMapper.queryById(Long.parseLong(electricianId));
			ElectricianVO electricianVO = null;
			if(null != electrician) {
				QueryWrapper<ElectricianCertificate> queryWrapper = new QueryWrapper<ElectricianCertificate>();
				queryWrapper.eq("electrician_id", electricianId);
				List<ElectricianCertificate> list = certificateMapper.selectList(queryWrapper);
				
				electricianVO = new ElectricianVO();
				BeanUtils.copyProperties(electrician, electricianVO);
				if(CollectionUtils.isNotEmpty(list)) {
					ElectricianCertificateVO electricianCertificateVO;
					List<ElectricianCertificateVO> newList = new ArrayList<>();
					for(ElectricianCertificate certificate : list) {
						electricianCertificateVO = new ElectricianCertificateVO();
						BeanUtils.copyProperties(certificate, electricianCertificateVO);
						newList.add(electricianCertificateVO);
					}
					electricianVO.setCertificateVOList(newList);
				}
				
			}
			result.setData(electricianVO);
		}catch(Exception e) {
			logger.error("queryElectricianById have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateStatusBatch(String[] electricianIds,Integer status) {
		Result result = new Result();
		try {
			UpdateWrapper<Electrician> updateWrapper = new UpdateWrapper<Electrician>();
			updateWrapper.in("electrician_id", electricianIds);
			Electrician electrician = new Electrician();
			electrician.setStatus(status);
			electricianMapper.update(electrician, updateWrapper);
		}catch(Exception e) {
			logger.error("updateStatusBatch have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result deleteElectricianById(String electricianId) {
		Result result = new Result();
		try {
			QueryWrapper<ElectricianCertificate> wrapper = new QueryWrapper<ElectricianCertificate>();
			wrapper.eq("electrician_id", electricianId);
			certificateMapper.delete(wrapper);
			UpdateWrapper<Electrician> updateWrapper = new UpdateWrapper<Electrician>();
			updateWrapper.eq("electrician_id", electricianId);
			Electrician electrician = new Electrician();
			electrician.setSysDeleted(1);
			electricianMapper.update(electrician, updateWrapper);
		}catch(Exception e) {
			logger.error("deleteElectricianById have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
			throw e;
		}
		return result;
	}

	@Override
	public DataResult<ElectricianVO> queryElectricianByUserId(String userId) {
		DataResult<ElectricianVO> result = new DataResult<ElectricianVO>();
		try {
			QueryWrapper<Electrician> queryWrapper = new QueryWrapper<Electrician>();
			queryWrapper.eq("user_id", userId);
			queryWrapper.eq("sys_deleted", 0);
			Electrician electrician = electricianMapper.selectOne(queryWrapper);
			if(null != electrician) {
				ElectricianVO electricianVO = new ElectricianVO();
				BeanUtils.copyProperties(electrician, electricianVO);
				result.setData(electricianVO);
			}
		}catch(Exception e) {
			logger.error("queryElectricianByUserId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateElectricianCid(String electricianId, String cid) {
		Result result = new Result();
		try {
			Electrician electrician = new Electrician();
			electrician.setCid(cid);
			electrician.setElectricianId(electricianId);
			electricianMapper.updateById(electrician);
		}catch(Exception e) {
			logger.error("updateElectricianCid have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<ElectricianVO> queryElectricianByUserIds(List<String> ids) {
		ListResult<ElectricianVO> result = new ListResult<ElectricianVO>();
		try {
			QueryWrapper<Electrician> queryWrapper = new QueryWrapper<Electrician>();
			queryWrapper.in("a.electrician_id", ids);
			List<Electrician> list = electricianMapper.selectElectricianByIds(queryWrapper);
			if(!CollectionUtils.isEmpty(list)) {
				ElectricianVO electricianVO;
				List<ElectricianVO> newList = new ArrayList<>();
				for(Electrician electrician : list) {
					electricianVO = new ElectricianVO();
					BeanUtils.copyProperties(electrician, electricianVO);
					newList.add(electricianVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryElectricianByUserIds have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateLocation(String electricianId, String lng, String lat) {
		Result result = new Result();
		Jedis jedis = RedisOperation.getRedis();
		try {
			//将获取到的电工定位信息缓存到redis中
			Electrician electrician = new Electrician();
			electrician.setElectricianId(electricianId);
			electrician.setLng(lng);
			electrician.setLat(lat);
			String location = lat+","+lng;
//			Integer cityCode = MapUtil.getCityCode(location);
			electricianMapper.updateById(electrician);
//			QueryWrapper<Electrician> queryWrapper = new QueryWrapper<Electrician>();
//			queryWrapper.eq("electrician_id", electricianId);
//			String cityCode = electricianMapper.selectServiceProviderCity(queryWrapper);
			String countCode = electricianGroupMapper.queryElectricianGroupCountCode(electricianId);
			if(null != countCode) {
				String key = UserConstants.LOACTION + countCode;
				jedis.hset(key,electricianId, location+","+System.currentTimeMillis());
			}else {
				result.setCode("-1");
				result.setMessage("没有电工对应的服务商城市信息！");
			}
			
		}catch(Exception e) {
			logger.error("updateLocation have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}finally {
			if(null != jedis) {
				jedis.close();
			}
		}
		return result;
	}

	@Override
	public ListResult<ElectricianVO> queryAssignElectrician(String address) {
		ListResult<ElectricianVO> result = new ListResult<ElectricianVO>();
		try {
			
			JSONObject mapResult = MapUtil.getLocation(address);
			if(null != mapResult) {
				Double lng = mapResult.getDouble("lng");
				Double lat = mapResult.getDouble("lat");
				QueryWrapper<Electrician> queryWrapper = new QueryWrapper<Electrician>();
				queryWrapper.eq("status", 1);
				queryWrapper.eq("sys_deleted", 0);
				List<Electrician> list = electricianMapper.selectList(queryWrapper);
				if(CollectionUtils.isNotEmpty(list)) {
					List<ElectricianVO> newList = new ArrayList<>();
					ElectricianVO electricianVO;
					Double distance;
					for(Electrician electrician : list) {
						distance = MapUtil.getDistance(lng, lat, electrician.getLng(), electrician.getLat());
						electricianVO = new ElectricianVO();
						BeanUtils.copyProperties(electrician, electricianVO);
						if(null != distance) {
							electricianVO.setDistance((distance/1000)+"");
						}
						
						newList.add(electricianVO);
						
					}
					result.setDataList(newList);
				}
				
			}
			
		}catch(Exception e) {
			logger.error("queryAssignElectrician have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<ElectricianVO> electricianLogin(String phone, String verificationCode, String cid) {
		DataResult<ElectricianVO> result = new DataResult<ElectricianVO>();
		Jedis jedis = null;
		try {
            QueryWrapper<Electrician> queryWrapper = new QueryWrapper<Electrician>();
            queryWrapper.eq("phone", phone);
            Electrician electrician = electricianMapper.selectOne(queryWrapper);
            if(null != electrician) {
            	String code = messageService.getVerificationCode(phone);
            	ElectricianVO electricianVO = new ElectricianVO();
            	BeanUtils.copyProperties(electrician, electricianVO);
        		result.setData(electricianVO);
        		if (StringUtils.equals(verificationCode, code) || "123456".equals(verificationCode)) {
                    //登陆成功
                	messageService.deleteVerificationCode(phone);
                	electrician.setCid(cid);
                	electricianMapper.updateById(electrician);
                } else {
                    //登陆失败
                    //返回错误信息
                	result.setCode("-1");
                	result.setMessage("验证码错误！");
                }
            }else {
            	result.setCode("-1");
            	result.setMessage("手机号码未注册！");
            }
			
		}catch(Exception e) {
			logger.error("appLogin have error={}",e);
//			e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
		}finally {
			if(null != jedis) {
				jedis.close();
			}
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result updateWorkStatus(String electricianId, Integer status) {
		Result result = new Result();
		try {
			Electrician electrician = new Electrician();
			electrician.setWorkStatus(status);
			electrician.setElectricianId(electricianId);
			electricianMapper.updateById(electrician);
		}catch(Exception e) {
			logger.error("appLogin have error={}",e);
//			e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
        	throw e;
		}
		return result;
	}

	@Override
	public ListResult<ElectricianVO> queryByServiceProviderCityCode(String cityCode,Double lng,Double lat) {
		ListResult<ElectricianVO> result = new ListResult<ElectricianVO>();
		try {
			List<Electrician> list = electricianMapper.queryElectricianByServiceProviderCityCode(cityCode);
			if(CollectionUtils.isNotEmpty(list)) {
				List<ElectricianVO> newList = new ArrayList<>();
				ElectricianVO electricianVO;
				Double distance;
				for(Electrician electrician : list) {
					distance = MapUtil.getDistance(lng, lat, electrician.getLng(), electrician.getLat());
					electricianVO = new ElectricianVO();
					BeanUtils.copyProperties(electrician, electricianVO);
					if(null != distance) {
						electricianVO.setDistance((distance/1000)+"");
					}
					newList.add(electricianVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryByServiceProviderCityCode have error={}",e);
//			e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
		return result;
	}

	@Override
	public ListResult<ElectricianVO> queryElectricianByServiceProviderId(String serviceProviderId,String groupId) {
		ListResult<ElectricianVO> result = new ListResult<ElectricianVO>();
		try {
			List<Electrician> list = electricianMapper.queryElectricianByServiceProviderId(serviceProviderId,groupId);
			if(CollectionUtils.isNotEmpty(list)) {
				List<ElectricianVO> newList = new ArrayList<>();
				ElectricianVO electricianVO;
				for(Electrician electrician : list) {
					electricianVO = new ElectricianVO();
					BeanUtils.copyProperties(electrician, electricianVO);
					newList.add(electricianVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryElectricianByServiceProviderId have error={}",e);
//			e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
		return result;
	}

	@Override
	public ListResult<ElectricianVO> queryByServiceProviderCountCode(String countCode, Double lng, Double lat) {
		ListResult<ElectricianVO> result = new ListResult<ElectricianVO>();
		try {
			List<Electrician> list = electricianMapper.queryElectricianByServiceProviderCountCode(countCode);
			if(CollectionUtils.isNotEmpty(list)) {
				List<ElectricianVO> newList = new ArrayList<>();
				ElectricianVO electricianVO;
				Double distance;
				for(Electrician electrician : list) {
					distance = MapUtil.getDistance(lng, lat, electrician.getLng(), electrician.getLat());
					electricianVO = new ElectricianVO();
					BeanUtils.copyProperties(electrician, electricianVO);
					if(null != distance) {
						electricianVO.setDistance((distance/1000)+"");
					}
					newList.add(electricianVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryByServiceProviderCountCode have error={}",e);
//			e.printStackTrace();
        	result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
		return result;
	}

	@Override
	public ListResult<ElectricianVO> queryAccompanyingElectrician(PageQuery query) {
		ListResult<ElectricianVO> result = new ListResult<ElectricianVO>();
		try {
			QueryWrapper<Electrician> queryWrapper = new QueryWrapper<Electrician>();
			List<FuzzyQuery> fuzzyList = query.getFuzzyList();
			if(CollectionUtils.isNotEmpty(fuzzyList)) {
				for(FuzzyQuery<?> fuzzy : fuzzyList) {
					if("dictionaries_id".equals(fuzzy.getColumn())) {
						queryWrapper.like(fuzzy.getColumn(), "1351073342146838531");
					}else {
						queryWrapper.like(fuzzy.getColumn(), fuzzy.getValue());
					}
					
				}
			}
			List<Electrician> list = electricianMapper.queryAccompanyingElectrician( queryWrapper);
			List<ElectricianVO> newList = new ArrayList<>();
			if(CollectionUtils.isNotEmpty(list)) {
				ElectricianVO electricianVO;
				for(Electrician electrician : list) {
					electricianVO = new ElectricianVO();
					BeanUtils.copyProperties(electrician, electricianVO);
					newList.add(electricianVO);
				}
			}
			result.setDataList(newList);
		}catch(Exception e) {
			logger.error("queryElectrician have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<String> queryServiceProviderDiscountByElectricianId(String electricianId) {
		
		DataResult<String> result = new DataResult<String>();
		try {
			String discount = electricianMapper.queryServiceProviderDiscountByElectricianId(electricianId);
			result.setData(discount);
		}catch(Exception e) {
			logger.error("queryServiceProviderDiscountByElectricianId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public PageResult<ElectricianVO> queryServiceProviderElectrician(PageQuery query) {
		PageResult<ElectricianVO> result = new PageResult<ElectricianVO>();
		try {
			QueryWrapper<Electrician> queryWrapper = new QueryWrapper<Electrician>();
			List<FuzzyQuery> fuzzyList = query.getFuzzyList();
			if(CollectionUtils.isNotEmpty(fuzzyList)) {
				boolean flage = false;
				for(FuzzyQuery<?> fuzzy : fuzzyList) {
					if("service_provider_id".equals(fuzzy.getColumn())) {
						flage = true;
						break;
					}
				}
				if(flage) {
					result = queryElectrician(query);
				}else {
					result.setCode("-1");
					result.setMessage("缺失服务商信息");
				}
			}else {
				result.setCode("-1");
				result.setMessage("缺失服务商信息");
			}
		}catch(Exception e) {
			logger.error("queryServiceProviderElectrician have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}
	
	

}
