package com.hp.user.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.apache.dubbo.common.utils.CollectionUtils;
import org.apache.dubbo.config.annotation.Service;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.FuzzyQuery;
import com.hp.user.client.entity.InspectionPlanVO;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.PageQuery;
import com.hp.user.client.entity.PageResult;
import com.hp.user.client.entity.PlanForUserVO;
import com.hp.user.client.entity.PlanVO;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.InspectionPlanService;
import com.hp.user.service.dao.InspectionPlanMapper;
import com.hp.user.service.dao.PlanElectricianMapper;
import com.hp.user.service.dao.PlanMapper;
import com.hp.user.service.dao.PlanStationMapper;
import com.hp.user.service.entity.InspectionPlan;
import com.hp.user.service.entity.Plan;
import com.hp.user.service.entity.PlanElectrician;
import com.hp.user.service.entity.PlanForUser;
import com.hp.user.service.entity.PlanStation;

@Service
public class InspectionPlanServiceImpl implements InspectionPlanService{
	
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	
	@Autowired
	private InspectionPlanMapper inspectionPlanMapper;
	
	@Autowired
	private PlanMapper planMapper;
	@Autowired
	private PlanStationMapper planStationMapper;
	
	@Autowired
	private PlanElectricianMapper planElectricianMapper;

	@Override
	@Transactional(rollbackFor = Exception.class)
	public Result createInspectionPlan(InspectionPlanVO inspectionPlanVO) {
		Result	result = new Result();
		try {
			
			String stationIds = inspectionPlanVO.getStationIds();
			if(StringUtils.isBlank(stationIds)) {
				result.setCode("-1");
				result.setMessage("站点列表不能为空");
				return result;
			}
			String planStart = inspectionPlanVO.getPlanStart();
			String planEnd = inspectionPlanVO.getPlanEnd();
			if(StringUtils.isAnyBlank(planStart,planEnd)) {
				result.setCode("-1");
				result.setMessage("计划开始结束时间不能为空");
				return result;
			}
			String cycleDay = inspectionPlanVO.getCycleDay();
			if(StringUtils.isBlank(cycleDay)) {
				result.setCode("-1");
				result.setMessage("巡检执行日期不能为空");
				return result;
			}
			String time = inspectionPlanVO.getInspectionTime();
			if(StringUtils.isBlank(time)) {
				result.setCode("-1");
				result.setMessage("巡检时间不能为空");
				return result;
			}
			String[] stationIdInfo = StringUtils.split(stationIds, ',');
			String planId = IdWorker.getIdStr();
			inspectionPlanVO.setPlanId(planId);
			List<PlanStation> planStationList = new ArrayList<>();
			PlanStation planStation;
			for(String stationId : stationIdInfo) {
				planStation = new PlanStation();
				planStation.setPlanId(planId);
				planStation.setStationId(stationId);
				planStationList.add(planStation);
			}
			planStationMapper.insertBatch(planStationList);
			InspectionPlan inspectionPlan = new InspectionPlan();
			BeanUtils.copyProperties(inspectionPlanVO, inspectionPlan);
			inspectionPlanMapper.insert(inspectionPlan);
		}catch(Exception e) {
			logger.error("createInspectionPlan have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
			throw e;
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public Result updateInspectionPlan(InspectionPlanVO inspectionPlanVO) {
		Result result = new Result();
		try {
			InspectionPlan inspectionPlan = new InspectionPlan();
			String stationIds = inspectionPlan.getStationIds();
			if(StringUtils.isBlank(stationIds)) {
				result.setCode("-1");
				result.setMessage("站点列表不能为空");
				return result;
			}
			String[] stationIdInfo = StringUtils.split(stationIds, ',');
			String planId = inspectionPlanVO.getPlanId();
			QueryWrapper<PlanStation> queryWrapper = new QueryWrapper<PlanStation>();
			queryWrapper.eq("plan_id", planId);
			planStationMapper.delete(queryWrapper);
			List<PlanStation> planStationList = new ArrayList<>();
			PlanStation planStation;
			for(String stationId : stationIdInfo) {
				planStation = new PlanStation();
				planStation.setPlanId(planId);
				planStation.setStationId(stationId);
				planStationList.add(planStation);
			}
			planStationMapper.insertBatch(planStationList);
			BeanUtils.copyProperties(inspectionPlanVO, inspectionPlan);
			inspectionPlanMapper.updateById(inspectionPlan);
		}catch(Exception e) {
			logger.error("updateInspectionPlan have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
			throw e;
		}
		return result;
	}

	@Override
	public PageResult<PlanVO> queryInspectionPlanByPageQuery(PageQuery query) {
		PageResult<PlanVO> result = new PageResult<PlanVO>();
		try {
			Integer page = query.getPage();
			Integer count = query.getSize();
			if(page == null || page == 0) {
				return result;
			}
			QueryWrapper<Plan> queryWrapper = new QueryWrapper<Plan>();
			List<FuzzyQuery> fuzzyList = query.getFuzzyList();
			if(CollectionUtils.isNotEmpty(fuzzyList)) {
				String column;
				Object value;
				String[] values;
				for(FuzzyQuery<?> fuzzy : fuzzyList) {
					column = fuzzy.getColumn();
					value = fuzzy.getValue();
					if(StringUtils.contains(column, "start")) {
						queryWrapper.ge("plan_end", value);
					}else if (StringUtils.contains(column, "end")){
						queryWrapper.le("plan_start", value);
					}else {
						queryWrapper.like(fuzzy.getColumn(), fuzzy.getValue());
					}
				}
			}
			List<Plan> list = null;
			Long total = null;
			if(page == -1) {
				queryWrapper.orderByDesc("plan_id");
				list = planMapper.selectList(queryWrapper);
			}else {
				Page<Plan> inspectionPlanPage = planMapper.queryPlanByQuey(new Page<>(page,count), queryWrapper);
				list = inspectionPlanPage.getRecords();
				total = inspectionPlanPage.getTotal();
			}
			List<PlanVO> newList = new ArrayList<>();
			if(CollectionUtils.isNotEmpty(list)) {
				PlanVO planVO;
				for(Plan plan : list) {
					planVO = new PlanVO();
					BeanUtils.copyProperties(plan, planVO);
					newList.add(planVO);
				}
				result.setTotal(total);
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryInspectionPlanByPageQuery have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public Result deleteInspectionPlan(String planId) {
		Result result = new Result();
		try {
			InspectionPlan inspectionPlan = new InspectionPlan();
			inspectionPlan.setPlanId(planId);
			inspectionPlan.setSysDeleted((short) 1);
			inspectionPlanMapper.updateById(inspectionPlan);
			QueryWrapper<PlanStation> queryWrapper = new QueryWrapper<PlanStation>();
			queryWrapper.eq("plan_id", planId);
			planStationMapper.delete(queryWrapper);
		}catch(Exception e) {
			logger.error("deleteInspectionPlan have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
			throw e;
		}
		return result;
	}

	@Override
	public DataResult<InspectionPlanVO> queryInspectionPlanById(String planId) {
		DataResult<InspectionPlanVO> result = new DataResult<InspectionPlanVO>();
		try {
			InspectionPlan inspectionPlan = inspectionPlanMapper.selectById(planId);
			if(null != inspectionPlan) {
				InspectionPlanVO inspectionPlanVO = new InspectionPlanVO();
				BeanUtils.copyProperties(inspectionPlan, inspectionPlanVO);
				result.setData(inspectionPlanVO);
			}
		}catch(Exception e) {
			logger.error("queryInspectionPlanById have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<PlanForUserVO> queryInspectionPlanByCompanyId(String companyId) {
		ListResult<PlanForUserVO> result = new ListResult<PlanForUserVO>();
		try {
			List<PlanForUser> list = inspectionPlanMapper.queryInspectionPlanByCompanyId(companyId);
			if(CollectionUtils.isNotEmpty(list)) {
				List<PlanForUserVO> newList = new ArrayList<>();
				PlanForUserVO planForUserVO;
				for(PlanForUser planForUser : list) {
					planForUserVO = new PlanForUserVO();
					BeanUtils.copyProperties(planForUser, planForUserVO);
					newList.add(planForUserVO);
				}
				result.setDataList(newList);
			}
			
		}catch(Exception e) {
			logger.error("queryInspectionPlanByUserPhone have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public Result distribution(String planId,String groupId,String electricianIds) {
		Result result = new Result();
		try {
			InspectionPlan inspectionPlan = inspectionPlanMapper.selectById(planId);
			if(null != inspectionPlan) {
				
				if(!StringUtils.isBlank(electricianIds)) {
					inspectionPlan.setGroupId(groupId);
					QueryWrapper<PlanElectrician> queryWrapper = new QueryWrapper<PlanElectrician>();
					queryWrapper.eq("plan_id", planId);
					planElectricianMapper.delete(queryWrapper);
//					inspectionPlan.setElectricianIds(electricianIds);
					String[] electricianInfo = StringUtils.split(electricianIds, ',');
					PlanElectrician planElectrician;
					List<PlanElectrician> list = new ArrayList<>();
					for(String electricianId : electricianInfo) {
						planElectrician = new PlanElectrician();
						planElectrician.setPlanId(planId);
						planElectrician.setElectricianId(electricianId);
						list.add(planElectrician);
					}
					planElectricianMapper.insertBatch(list);
					inspectionPlanMapper.updateById(inspectionPlan);
				}else {
					result.setCode("-1");
					result.setMessage("电工列表不能为空");
				}
			}else {
				result.setCode("-1");
				result.setMessage("计划不存在");
			}
		}catch(Exception e) {
			logger.error("distribution have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
			throw e;
		}
		return result;
	}

}
