package com.hp.user.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.InspectionResultVO;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.InspectionResultService;
import com.hp.user.service.dao.CustomerCompanyMapper;
import com.hp.user.service.dao.InspectionResultMapper;
import com.hp.user.service.entity.CustomerCompany;
import com.hp.user.service.entity.InspectionResult;

public class InspectionResultServiceImpl implements InspectionResultService {
	
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	
	@Autowired
	private InspectionResultMapper inspectionResultMapper;
	
	@Autowired
    private CustomerCompanyMapper customerCompanyMapper;

	@Override
	public Result createInspectionResult(List<InspectionResultVO> inspectionResultVOList) {
		Result result = new Result();
		try {
			
			
			if(CollectionUtils.isNotEmpty(inspectionResultVOList)) {
				InspectionResult inspectionResult;
				List<InspectionResult> list = new ArrayList<>();
				String resultId;
				for(InspectionResultVO inspectionResultVO : inspectionResultVOList) {
					inspectionResult = new InspectionResult();
					BeanUtils.copyProperties(inspectionResultVO, inspectionResult);
					resultId = IdWorker.getIdStr();
					inspectionResult.setResultId(resultId);
					list.add(inspectionResult);
				}
				inspectionResultMapper.insertBatch(list);
			}
		}catch(Exception e) {
			logger.error("createInspectionResult have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateInspectionResult(List<InspectionResultVO> inspectionResultVOList) {
		Result result = new Result();
		try {
			if(CollectionUtils.isNotEmpty(inspectionResultVOList)) {
				InspectionResult inspectionResult;
				List<InspectionResult> list = new ArrayList<>();
				for(InspectionResultVO inspectionResultVO : inspectionResultVOList) {
					inspectionResult = new InspectionResult();
					BeanUtils.copyProperties(inspectionResultVO, inspectionResult);
					list.add(inspectionResult);
				}
				inspectionResultMapper.updateBatch(list);
			}
		}catch(Exception e) {
			logger.error("updateInspectionResult have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<InspectionResultVO> queryInspectionResult(String workOrderId, String deviceId) {
		ListResult<InspectionResultVO> result = new ListResult<InspectionResultVO>();
		try {
			QueryWrapper<InspectionResult> queryWrapper = new QueryWrapper<InspectionResult>();
			queryWrapper.eq("work_order_id", workOrderId);
			queryWrapper.eq("device_id", deviceId);
			List<InspectionResult> list = inspectionResultMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				List<InspectionResultVO> newList = new ArrayList<InspectionResultVO>();
				InspectionResultVO inspectionResultVO;
				for(InspectionResult inspectionResult : list) {
					inspectionResultVO = new InspectionResultVO();
					BeanUtils.copyProperties(inspectionResult, inspectionResultVO);
					newList.add(inspectionResultVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryInspectionResult have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<String> queryInspectionResultByWorkOrderId(String workOrderId,String phone) {
		DataResult<String> result = new DataResult<String>();
		try {
			QueryWrapper<CustomerCompany> customerQueryWrapper = new QueryWrapper<CustomerCompany>();
			customerQueryWrapper.eq("phone_number", phone);
			customerQueryWrapper.eq("sys_deleted", 0);
			CustomerCompany customerCompany = customerCompanyMapper.selectOne(customerQueryWrapper);
			if(null == customerCompany) {
				result.setCode("-1");
				result.setMessage("根据手机号没有查到对应的企业");
				return result;
			}
			String customerId = customerCompany.getCustomerId();
			QueryWrapper<InspectionResult> queryWrapper = new QueryWrapper<InspectionResult>();
			queryWrapper.eq("work_order_id", workOrderId);
			List<InspectionResult> list = inspectionResultMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				List<InspectionResultVO> newList = new ArrayList<InspectionResultVO>();
				InspectionResultVO inspectionResultVO;
				for(InspectionResult inspectionResult : list) {
					inspectionResultVO = new InspectionResultVO();
					BeanUtils.copyProperties(inspectionResult, inspectionResultVO);
					newList.add(inspectionResultVO);
				}
			}
		}catch(Exception e) {
			logger.error("queryInspectionResultByWorkOrderId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public DataResult<Integer> queryInspectionResultAbnormalStatusCountByWorkOrderId(String workOrderId) {
		DataResult<Integer> result = new DataResult<Integer>();
		try {
			QueryWrapper<InspectionResult> queryWrapper = new QueryWrapper<InspectionResult>();
			queryWrapper.eq("work_order_id", workOrderId);
			queryWrapper.eq("result", 2);
			Integer count = inspectionResultMapper.selectCount(null);
			result.setData(count);
		}catch(Exception e) {
			logger.error("queryInspectionResultByWorkOrderId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

}
