package com.hp.user.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.hp.user.client.entity.*;
import com.hp.user.client.service.StationService;
import com.hp.user.service.dao.StationMapper;
import com.hp.user.service.entity.Station;
import com.hp.user.service.utils.MapUtil;

import org.apache.commons.lang3.StringUtils;
import org.apache.dubbo.common.utils.CollectionUtils;
import org.apache.dubbo.config.annotation.Service;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * <p>
 * 站点信息 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
@Service
public class StationServiceImpl implements StationService {
	
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private StationMapper stationMapper;

    @Override
    @Transactional(rollbackFor = {Exception.class})
    public Result insert(StationVO station) {
        Station temp = new Station();
        Result result = new Result();
        int flag=0;
        try{
        	String lng = station.getLng();
        	String lat = station.getLat();
        	String stationName = station.getName();
        	QueryWrapper<Station> queryWrapper = new QueryWrapper<Station>();
        	queryWrapper.eq("name", stationName);
        	queryWrapper.eq("sys_deleted", 0);
        	Integer count = stationMapper.selectCount(queryWrapper);
        	if(count > 0) {
        		result.setCode("-1");
                result.setMessage("站点名称已经存在");
                return result;
        	}
        	if(StringUtils.isAnyBlank(lng,lat)) {
        		result.setCode("-1");
                result.setMessage("百度坐标系不能为空");
                return result;
        	}else {
        		String gcj02Lng = station.getGcj02Lng();
        		String gcj02Lat = station.getGcj02Lat();
        		if(StringUtils.isNoneBlank(gcj02Lng,gcj02Lat)) {
        			String gcj02Location = MapUtil.getGcj02FromBaidu(lng,lat);
					if(null != gcj02Location) {
						String[] gcj02LocationInfo = StringUtils.split(gcj02Location, ',');
						String gcj02lng = gcj02LocationInfo[0];
						String gcj02lat = gcj02LocationInfo[1];
						station.setGcj02Lng(gcj02lng);
						station.setGcj02Lat(gcj02lat);
					}else {
						
					}
            	}
        	}
            BeanUtils.copyProperties(station, temp);
            flag = stationMapper.insert(temp);
            // 判断数据库操作是否成功
            if(SqlHelper.retBool(flag)){
                result.setCode("0");
            } else {
                result.setCode("-1");
                result.setMessage("添加失败");
            }
        }catch(Exception e) {
        	logger.error("insert have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
        	throw e;
		}
        
        return result;
    }

    @Override
    public Result delete(String stationId) {
        // 将deleted字段设置为1
        Station temp;
        int flag=0;
        Result result = new Result();
        try{
            temp = stationMapper.selectById(stationId);
            if(temp==null){
                result.setCode("-1");
                result.setMessage("未查找到此站点");
                return result;
            }
            temp.setSysDeleted((short) 1);
            flag = stationMapper.updateById(temp);
            if (SqlHelper.retBool(flag)) {
                result.setCode("0");
            } else {
                result.setCode("-1");
                result.setMessage("删除失败");
            }
        }catch(Exception e) {
        	logger.error("delete have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
        
        return result;
    }

    @Override
    public Result update(StationVO station) {
        Station temp = new Station();
        Result result = new Result();
        int flag=0;
        try{
            BeanUtils.copyProperties(station, temp);
            flag = stationMapper.updateById(temp);
            // 判断数据库操作是否成功
            if (SqlHelper.retBool(flag)) {
                result.setCode("0");
            } else {
                result.setCode("-1");
                result.setMessage("更新失败");
            }
        }catch(Exception e) {
        	logger.error("update have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
        
        return result;
    }

    @Override
    public DataResult<StationVO> queryStationByStationId(String stationId) {
        StationVO stationVO = new StationVO();
        DataResult<StationVO> result = new DataResult<>();
        try{
            Station temp = stationMapper.selectById(stationId);
            if (temp == null || temp.getSysDeleted() == 1) {
                result.setCode("-1");
                result.setMessage("站点不存在/已删除");
                return result;
            }
            else {
                BeanUtils.copyProperties(temp, stationVO);
                result.setCode("0");
                result.setData(stationVO);
            }
        }catch(Exception e) {
        	logger.error("queryStationByStationId have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
        return result;
    }

    @Override
    public DataResult<StationVO> queryStationByStationName(String name) {
        StationVO stationVO = new StationVO();
        DataResult<StationVO> result= new DataResult<>();
        QueryWrapper<Station> wrapper = new QueryWrapper<>();
        try{
            wrapper.like("name", name);
            wrapper.eq("sys_deleted", 0);
            Station station = stationMapper.selectOne(wrapper);
            if (station == null) {
                result.setCode("-1");
                result.setMessage("站点不存在/已删除");
                return result;
            }
            else {
                BeanUtils.copyProperties(station, stationVO);
                result.setCode("0");
                result.setData(stationVO);
            }
        }catch(Exception e) {
        	logger.error("queryStationByStationName have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
        return result;
    }

    @Override
    public PageResult<StationVO> queryAllStationsPageByCompanyIdAndStationName(String companyId,String stationName,Long current, Integer size){
        PageResult<StationVO> result = new PageResult<>();
        List<StationVO> stationVOList = new ArrayList<>();
        IPage<Station> page = new Page<>(current, size);
        QueryWrapper<Station> wrapper = new QueryWrapper<>();
        try{
            if(companyId==null){
                result.setCode("-1");
                result.setMessage("企业Id 不能为空");
                return result;
            }
            wrapper.eq("enterprise_id", companyId);
            if (stationName != null) wrapper.like("name", stationName);
            wrapper.orderByDesc("sys_create_time");
            wrapper.eq("sys_deleted", 0);
            stationMapper.selectPage(page, wrapper);
            List<Station> stations = page.getRecords();
            StationVO temp;
            for (Station station : stations) {
                temp = new StationVO();
                BeanUtils.copyProperties(station, temp);
                stationVOList.add(temp);
            }
            result.setCode("0");
            result.setDataList(stationVOList);
            result.setTotal(page.getTotal());
            result.setCurrent(current);
            result.setSize(size);
            return result;
        }catch(Exception e) {
        	logger.error("queryAllStationsPageByCompanyIdAndStationName have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
        return result;
    }

	@Override
	public ListResult<StationVO> queryStationByStationIds(String stationIds) {
		ListResult<StationVO> result = new ListResult<StationVO>();
		try {
			List<Station> list = stationMapper.selectBatchIds(Arrays.asList(StringUtils.split(stationIds, ',')));
			if(CollectionUtils.isNotEmpty(list)) {
				StationVO stationVO;
				List<StationVO> newList = new ArrayList<>();
				for(Station station : list) {
					stationVO = new StationVO();
					BeanUtils.copyProperties(station, stationVO);
					newList.add(stationVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryStationByStationIds have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
		return result;
	}

	@Override
	public ListResult<StationVO> queryStationsByServiceProviderId(String serviceProviderId) {
		ListResult<StationVO> result = new ListResult<StationVO>();
		try {
			List<Station> list = stationMapper.queryStationsByServiceProviderId(serviceProviderId);
			if(CollectionUtils.isNotEmpty(list)) {
				List<StationVO> newList = new ArrayList<>();
				StationVO stationVO;
				for(Station station : list) {
					stationVO = new StationVO();
					BeanUtils.copyProperties(station, stationVO);
					newList.add(stationVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryStationsByServiceProviderId have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
		return result;
	}

	@Override
	public ListResult<String> queryStationIdsByCompanyId(String companyId) {
		ListResult<String> result = new ListResult<String>();
		try {
			List<String> list = stationMapper.queryStationIdsByCompanyId(companyId);
			result.setDataList(list);
		}catch(Exception e) {
			logger.error("queryStationIdsByCompanyId have error={}",e);
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
		return result;
	}
}
