package com.hp.user.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.dubbo.common.utils.CollectionUtils;
import org.apache.dubbo.config.annotation.Service;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.hp.user.client.entity.ListResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.entity.SurveyDcScreenVO;
import com.hp.user.client.entity.SurveyHighVoltageSwitchCabinetVO;
import com.hp.user.client.entity.SurveyLowVoltageSwitchCabinetVO;
import com.hp.user.client.entity.SurveyReactivePowerCompensationVO;
import com.hp.user.client.entity.SurveySubstationDeviceVO;
import com.hp.user.client.entity.SurveySubstationVO;
import com.hp.user.client.entity.SurveyTransformerVO;
import com.hp.user.client.service.SurveyDeviceManagerService;
import com.hp.user.service.dao.SurveyDcScreenMapper;
import com.hp.user.service.dao.SurveyHighVoltageSwitchMapper;
import com.hp.user.service.dao.SurveyLowVoltageSwitchCabinetMapper;
import com.hp.user.service.dao.SurveyReactivePowerCompensationMapper;
import com.hp.user.service.dao.SurveySubstationDeviceMapper;
import com.hp.user.service.dao.SurveySubstationMapper;
import com.hp.user.service.dao.SurveyTransformerMapper;
import com.hp.user.service.entity.SurveyDcScreen;
import com.hp.user.service.entity.SurveyHighVoltageSwitchCabinet;
import com.hp.user.service.entity.SurveyLowVoltageSwitchCabinet;
import com.hp.user.service.entity.SurveyReactivePowerCompensation;
import com.hp.user.service.entity.SurveySubstation;
import com.hp.user.service.entity.SurveySubstationDevice;
import com.hp.user.service.entity.SurveyTransformer;

@Service
public class SurveyDeviceManagerServiceImpl implements SurveyDeviceManagerService {
	
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	
	@Autowired
	private SurveySubstationMapper surveySubstationMapper;
	
	@Autowired
	private SurveyTransformerMapper surveyTransformerMapper;
	
	@Autowired
	private SurveyReactivePowerCompensationMapper surveyReactivePowerCompensationMapper;
	
	@Autowired
	private SurveyLowVoltageSwitchCabinetMapper surveyLowVoltageSwitchCabinetMapper;
	
	@Autowired
	private SurveyHighVoltageSwitchMapper surveyHighVoltageSwitchMapper;
	
	@Autowired
	private SurveyDcScreenMapper surveyDcScreenMapper;
	@Autowired
	private SurveySubstationDeviceMapper surveySubstationDeviceMapper;
	

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createSubstation(SurveySubstationVO surveySubstationVO) {
		Result result = new Result();
		try {
			String deviceName = surveySubstationVO.getDeviceName();
			String stationId = surveySubstationVO.getStationId();
			QueryWrapper<SurveySubstation> queryWrapper = new QueryWrapper<SurveySubstation>();
			queryWrapper.eq("device_name", deviceName);
			queryWrapper.eq("station_id", stationId);
			queryWrapper.eq("sys_status", 0);
			
			SurveySubstation surveySubstation = surveySubstationMapper.selectOne(queryWrapper);
			if(null != surveySubstation) {
				result.setCode("-1");
				result.setMessage("配电房名称已经存在");
				return result;
			}
			BeanUtils.copyProperties(surveySubstationVO, surveySubstation);
			surveySubstationMapper.insert(surveySubstation);
		}catch(Exception e) {
			logger.error("createSubstation have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createTransformer(SurveyTransformerVO surveyTransformerVO) {
		Result result = new Result();
		try {
			SurveyTransformer surveyTransformer = new SurveyTransformer();
			String deviceId = IdWorker.getIdStr();
			surveyTransformerVO.setDeviceId(deviceId);
			BeanUtils.copyProperties(surveyTransformerVO, surveyTransformer);
			surveyTransformerMapper.insert(surveyTransformer);
			SurveySubstationDevice surveySubstationDevice = new SurveySubstationDevice();
			String substionId = surveyTransformerVO.getSubstationId();
			String deviceName = surveyTransformerVO.getDeviceName();
			surveySubstationDevice.setSubstationId(substionId);
			surveySubstationDevice.setDeviceId(deviceId);
			surveySubstationDevice.setDeviceName(deviceName);
			surveySubstationDevice.setDeviceType("13001");
			surveySubstationDeviceMapper.insert(surveySubstationDevice);
		}catch(Exception e) {
			logger.error("createTransformer have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createSurveyHighVoltageSwitchCabinet(
			SurveyHighVoltageSwitchCabinetVO surveyHighVoltageSwitchCabinetVO) {
		Result result = new Result();
		try {
			SurveyHighVoltageSwitchCabinet surveyHighVoltageSwitchCabinet =  new SurveyHighVoltageSwitchCabinet();
			String deviceId = IdWorker.getIdStr();
			surveyHighVoltageSwitchCabinetVO.setDeviceId(deviceId);
			BeanUtils.copyProperties(surveyHighVoltageSwitchCabinetVO, surveyHighVoltageSwitchCabinet);
			surveyHighVoltageSwitchMapper.insert(surveyHighVoltageSwitchCabinet);
			SurveySubstationDevice surveySubstationDevice = new SurveySubstationDevice();
			String substionId = surveyHighVoltageSwitchCabinetVO.getSubstationId();
			String deviceName = surveyHighVoltageSwitchCabinetVO.getDeviceName();
			surveySubstationDevice.setSubstationId(substionId);
			surveySubstationDevice.setDeviceId(deviceId);
			surveySubstationDevice.setDeviceName(deviceName);
			surveySubstationDevice.setDeviceType("13002");
			surveySubstationDeviceMapper.insert(surveySubstationDevice);
		}catch(Exception e) {
			logger.error("createSurveyHighVoltageSwitchCabinet have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createSurveyLowVoltageSwitchCabinet(SurveyLowVoltageSwitchCabinetVO surveyLowVoltageSwitchCabinetVO) {
		Result result = new Result();
		try {
			SurveyLowVoltageSwitchCabinet surveyLowVoltageSwitchCabinet = new SurveyLowVoltageSwitchCabinet();
			String deviceId = IdWorker.getIdStr();
			surveyLowVoltageSwitchCabinetVO.setDeviceId(deviceId);
			BeanUtils.copyProperties(surveyLowVoltageSwitchCabinetVO, surveyLowVoltageSwitchCabinet);
			surveyLowVoltageSwitchCabinetMapper.insert(surveyLowVoltageSwitchCabinet);
			SurveySubstationDevice surveySubstationDevice = new SurveySubstationDevice();
			String substionId = surveyLowVoltageSwitchCabinetVO.getSubstationId();
			String deviceName = surveyLowVoltageSwitchCabinetVO.getDeviceName();
			surveySubstationDevice.setSubstationId(substionId);
			surveySubstationDevice.setDeviceId(deviceId);
			surveySubstationDevice.setDeviceName(deviceName);
			surveySubstationDevice.setDeviceType("13003");
			surveySubstationDeviceMapper.insert(surveySubstationDevice);
		}catch(Exception e) {
			logger.error("createSurveyLowVoltageSwitchCabinet have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createReactivePowerCompensation(SurveyReactivePowerCompensationVO surveyReactivePowerCompensationVO) {
		Result result = new Result();
		try {
			SurveyReactivePowerCompensation surveyReactivePowerCompensation = new SurveyReactivePowerCompensation();
			String deviceId = IdWorker.getIdStr();
			surveyReactivePowerCompensationVO.setDeviceId(deviceId);
			BeanUtils.copyProperties(surveyReactivePowerCompensationVO, surveyReactivePowerCompensation);
			surveyReactivePowerCompensationMapper.insert(surveyReactivePowerCompensation);
			SurveySubstationDevice surveySubstationDevice = new SurveySubstationDevice();
			String substionId = surveyReactivePowerCompensationVO.getSubstationId();
			String deviceName = surveyReactivePowerCompensationVO.getDeviceName();
			surveySubstationDevice.setSubstationId(substionId);
			surveySubstationDevice.setDeviceId(deviceId);
			surveySubstationDevice.setDeviceName(deviceName);
			surveySubstationDevice.setDeviceType("13004");
			surveySubstationDeviceMapper.insert(surveySubstationDevice);
		}catch(Exception e) {
			logger.error("createReactivePowerCompensation have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	@Transactional(rollbackFor = {Exception.class})
	public Result createDcScreen(SurveyDcScreenVO surveyDcScreenVO) {
		Result result = new Result();
		try {
			SurveyDcScreen surveyDcScreen = new SurveyDcScreen();
			String deviceId = IdWorker.getIdStr();
			surveyDcScreenVO.setDeviceId(deviceId);
			BeanUtils.copyProperties(surveyDcScreenVO, surveyDcScreen);
			surveyDcScreenMapper.insert(surveyDcScreen);
			SurveySubstationDevice surveySubstationDevice = new SurveySubstationDevice();
			String substionId = surveyDcScreenVO.getSubstationId();
			String deviceName = surveyDcScreenVO.getDeviceName();
			surveySubstationDevice.setSubstationId(substionId);
			surveySubstationDevice.setDeviceId(deviceId);
			surveySubstationDevice.setDeviceName(deviceName);
			surveySubstationDevice.setDeviceType("13005");
			surveySubstationDeviceMapper.insert(surveySubstationDevice);
		}catch(Exception e) {
			logger.error("createDcScreen have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<SurveySubstationVO> querySubstationByStationId(String stationId) {
		ListResult<SurveySubstationVO> result = new ListResult<SurveySubstationVO>();
		try {
			
			QueryWrapper<SurveySubstation> queryWrapper = new QueryWrapper<SurveySubstation>();
			queryWrapper.eq("station_id", stationId);
			List<SurveySubstation> list = surveySubstationMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				SurveySubstationVO surveySubstationVO;
				List<SurveySubstationVO> newList = new ArrayList<>();
				for(SurveySubstation surveySubstation  : list) {
					surveySubstationVO = new SurveySubstationVO();
					BeanUtils.copyProperties(surveySubstation, surveySubstationVO);
					newList.add(surveySubstationVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("querySubstationByStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<SurveyTransformerVO> queryTransformerBySubStationId(String subStationId) {
		ListResult<SurveyTransformerVO> result = new ListResult<SurveyTransformerVO>();
		try {
			QueryWrapper<SurveyTransformer> queryWrapper = new QueryWrapper<SurveyTransformer>();
			queryWrapper.eq("substation_id", subStationId);
			List<SurveyTransformer> list = surveyTransformerMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				SurveyTransformerVO surveyTransformerVO;
				List<SurveyTransformerVO> newList = new ArrayList<>();
				for(SurveyTransformer surveyTransformer  : list) {
					surveyTransformerVO = new SurveyTransformerVO();
					BeanUtils.copyProperties(surveyTransformer, surveyTransformerVO);
					newList.add(surveyTransformerVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryTransformerBySubStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<SurveyHighVoltageSwitchCabinetVO> querySurveyHighVoltageSwitchCabinetBySubStationId(
			String subStationId) {
		ListResult<SurveyHighVoltageSwitchCabinetVO> result = new ListResult<SurveyHighVoltageSwitchCabinetVO>();
		try {
			QueryWrapper<SurveyHighVoltageSwitchCabinet> queryWrapper = new QueryWrapper<SurveyHighVoltageSwitchCabinet>();
			queryWrapper.eq("substation_id", subStationId);
			List<SurveyHighVoltageSwitchCabinet> list = surveyHighVoltageSwitchMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				SurveyHighVoltageSwitchCabinetVO surveyHighVoltageSwitchCabinetVO;
				List<SurveyHighVoltageSwitchCabinetVO> newList = new ArrayList<>();
				for(SurveyHighVoltageSwitchCabinet surveyHighVoltageSwitchCabinet  : list) {
					surveyHighVoltageSwitchCabinetVO = new SurveyHighVoltageSwitchCabinetVO();
					BeanUtils.copyProperties(surveyHighVoltageSwitchCabinet, surveyHighVoltageSwitchCabinetVO);
					newList.add(surveyHighVoltageSwitchCabinetVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("querySurveyHighVoltageSwitchCabinetBySubStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<SurveyLowVoltageSwitchCabinetVO> querySurveyLowVoltageSwitchCabinetBySubStationId(
			String subStationId) {
		ListResult<SurveyLowVoltageSwitchCabinetVO> result = new ListResult<SurveyLowVoltageSwitchCabinetVO>();
		try {
			QueryWrapper<SurveyLowVoltageSwitchCabinet> queryWrapper = new QueryWrapper<SurveyLowVoltageSwitchCabinet>();
			queryWrapper.eq("substation_id", subStationId);
			List<SurveyLowVoltageSwitchCabinet> list = surveyLowVoltageSwitchCabinetMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				SurveyLowVoltageSwitchCabinetVO surveyLowVoltageSwitchCabinetVO;
				List<SurveyLowVoltageSwitchCabinetVO> newList = new ArrayList<>();
				for(SurveyLowVoltageSwitchCabinet surveyLowVoltageSwitchCabinet  : list) {
					surveyLowVoltageSwitchCabinetVO = new SurveyLowVoltageSwitchCabinetVO();
					BeanUtils.copyProperties(surveyLowVoltageSwitchCabinet, surveyLowVoltageSwitchCabinetVO);
					newList.add(surveyLowVoltageSwitchCabinetVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("querySurveyLowVoltageSwitchCabinetBySubStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<SurveyReactivePowerCompensationVO> queryReactivePowerCompensationBySubStationId(
			String subStationId) {
		ListResult<SurveyReactivePowerCompensationVO> result = new ListResult<SurveyReactivePowerCompensationVO>();
		try {
			QueryWrapper<SurveyReactivePowerCompensation> queryWrapper = new QueryWrapper<SurveyReactivePowerCompensation>();
			queryWrapper.eq("substation_id", subStationId);
			List<SurveyReactivePowerCompensation> list = surveyReactivePowerCompensationMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				SurveyReactivePowerCompensationVO surveyReactivePowerCompensationVO;
				List<SurveyReactivePowerCompensationVO> newList = new ArrayList<>();
				for(SurveyReactivePowerCompensation surveyReactivePowerCompensation  : list) {
					surveyReactivePowerCompensationVO = new SurveyReactivePowerCompensationVO();
					BeanUtils.copyProperties(surveyReactivePowerCompensation, surveyReactivePowerCompensationVO);
					newList.add(surveyReactivePowerCompensationVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryReactivePowerCompensationBySubStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<SurveyDcScreenVO> queryDcScreenBySubStationId(String subStationId) {
		ListResult<SurveyDcScreenVO> result = new ListResult<SurveyDcScreenVO>();
		try {
			QueryWrapper<SurveyDcScreen> queryWrapper = new QueryWrapper<SurveyDcScreen>();
			queryWrapper.eq("substation_id", subStationId);
			List<SurveyDcScreen> list = surveyDcScreenMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				SurveyDcScreenVO surveyDcScreenVO;
				List<SurveyDcScreenVO> newList = new ArrayList<>();
				for(SurveyDcScreen surveyDcScreen  : list) {
					surveyDcScreenVO = new SurveyDcScreenVO();
					BeanUtils.copyProperties(surveyDcScreen, surveyDcScreenVO);
					newList.add(surveyDcScreenVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("queryDcScreenBySubStationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateSubstation(SurveySubstationVO surveySubstationVO) {
		Result result = new Result();
		try {
			SurveySubstation surveySubstation = new SurveySubstation();
			BeanUtils.copyProperties(surveySubstationVO, surveySubstation);
			surveySubstationMapper.updateById(surveySubstation);
		}catch(Exception e) {
			logger.error("updateSubstation have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateTransformer(SurveyTransformerVO surveyTransformerVO) {
		Result result = new Result();
		try {
			SurveyTransformer surveyTransformer = new SurveyTransformer();
			BeanUtils.copyProperties(surveyTransformerVO, surveyTransformer);
			surveyTransformerMapper.updateById(surveyTransformer);
		}catch(Exception e) {
			logger.error("updateTransformer have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateHighVoltageSwitchCabinet(SurveyHighVoltageSwitchCabinetVO surveyHighVoltageSwitchCabinetVO) {
		Result result = new Result();
		try {
			SurveyHighVoltageSwitchCabinet surveyHighVoltageSwitchCabinet = new SurveyHighVoltageSwitchCabinet();
			BeanUtils.copyProperties(surveyHighVoltageSwitchCabinetVO, surveyHighVoltageSwitchCabinet);
			surveyHighVoltageSwitchMapper.updateById(surveyHighVoltageSwitchCabinet);
		}catch(Exception e) {
			logger.error("updateHighVoltageSwitchCabinet have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateLowVoltageSwitchCabinet(SurveyLowVoltageSwitchCabinetVO surveyLowVoltageSwitchCabinetVO) {
		Result result = new Result();
		try {
			SurveyLowVoltageSwitchCabinet surveyLowVoltageSwitchCabinet = new SurveyLowVoltageSwitchCabinet();
			BeanUtils.copyProperties(surveyLowVoltageSwitchCabinetVO, surveyLowVoltageSwitchCabinet);
			surveyLowVoltageSwitchCabinetMapper.updateById(surveyLowVoltageSwitchCabinet);
		}catch(Exception e) {
			logger.error("updateLowVoltageSwitchCabinet have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateReactivePowerCompensation(SurveyReactivePowerCompensationVO surveyReactivePowerCompensationVO) {
		Result result = new Result();
		try {
			SurveyReactivePowerCompensation surveyReactivePowerCompensation = new SurveyReactivePowerCompensation();
			BeanUtils.copyProperties(surveyReactivePowerCompensationVO, surveyReactivePowerCompensation);
			surveyReactivePowerCompensationMapper.updateById(surveyReactivePowerCompensation);
		}catch(Exception e) {
			logger.error("updateReactivePowerCompensation have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public Result updateDcScreen(SurveyDcScreenVO surveyDcScreenVO) {
		Result result = new Result();
		try {
			SurveyDcScreen surveyDcScreen = new SurveyDcScreen();
			BeanUtils.copyProperties(surveyDcScreenVO, surveyDcScreen);
			surveyDcScreenMapper.updateById(surveyDcScreen);
		}catch(Exception e) {
			logger.error("updateDcScreen have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<SurveySubstationDeviceVO> querySubstionAllDeviceBySubstationId(String substationId) {
		ListResult<SurveySubstationDeviceVO> result = new ListResult<SurveySubstationDeviceVO>();
		try {
			QueryWrapper<SurveySubstationDevice> queryWrapper = new QueryWrapper<SurveySubstationDevice>();
			List<SurveySubstationDevice> list = surveySubstationDeviceMapper.selectList(queryWrapper);
			if(CollectionUtils.isNotEmpty(list)) {
				SurveySubstationDeviceVO surveySubstationDeviceVO;
				List<SurveySubstationDeviceVO> newList = new ArrayList<>();
				for(SurveySubstationDevice surveySubstationDevice : list) {
					surveySubstationDeviceVO = new SurveySubstationDeviceVO();
					BeanUtils.copyProperties(surveySubstationDevice, surveySubstationDeviceVO);
					newList.add(surveySubstationDeviceVO);
				}
				result.setDataList(newList);
			}
		}catch(Exception e) {
			logger.error("querySubstionAllDeviceBySubstationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

	@Override
	public ListResult<Object> querySubstionAllDeviceInfoBySubstationId(String substationId) {
		ListResult<Object> result = new ListResult<Object>();
		try {
			List<Object> list = new ArrayList<>();
			QueryWrapper<SurveyTransformer> transformerQueryWrapper = new QueryWrapper<SurveyTransformer>();
			transformerQueryWrapper.eq("substation_id", substationId);
			List<SurveyTransformer> transformerList =  surveyTransformerMapper.selectList(transformerQueryWrapper);
			list.addAll(transformerList);
			QueryWrapper<SurveyReactivePowerCompensation> reactivePowerCompensationQueryWrapper = new QueryWrapper<SurveyReactivePowerCompensation>();
			reactivePowerCompensationQueryWrapper.eq("substation_id", substationId);
			List<SurveyReactivePowerCompensation> reactivePowerCompensationList = surveyReactivePowerCompensationMapper.selectList(reactivePowerCompensationQueryWrapper);
			list.addAll(reactivePowerCompensationList);
			QueryWrapper<SurveyLowVoltageSwitchCabinet> lowVoltageSwitchCabinetQueryWrapper = new QueryWrapper<SurveyLowVoltageSwitchCabinet>();
			lowVoltageSwitchCabinetQueryWrapper.eq("substation_id", substationId);
			List<SurveyLowVoltageSwitchCabinet> lowVoltageSwitchCabinetList = surveyLowVoltageSwitchCabinetMapper.selectList(lowVoltageSwitchCabinetQueryWrapper);
			list.addAll(lowVoltageSwitchCabinetList);
			QueryWrapper<SurveyHighVoltageSwitchCabinet> highVoltageSwitchQueryWrapper = new QueryWrapper<SurveyHighVoltageSwitchCabinet>();
			highVoltageSwitchQueryWrapper.eq("substation_id", substationId);
			List<SurveyHighVoltageSwitchCabinet> highVoltageSwitchCabinetList = surveyHighVoltageSwitchMapper.selectList(highVoltageSwitchQueryWrapper);
			list.addAll(highVoltageSwitchCabinetList);
			QueryWrapper<SurveyDcScreen> dcScreenQueryWrapper = new QueryWrapper<SurveyDcScreen>();
			dcScreenQueryWrapper.eq("substation_id", substationId);
			List<SurveyDcScreen> surveyDcScreenList = surveyDcScreenMapper.selectList(dcScreenQueryWrapper);
			list.addAll(surveyDcScreenList);
			result.setDataList(list);
		}catch(Exception e) {
			logger.error("querySubstionAllDeviceInfoBySubstationId have error={}",e);
			result.setCode("-1");
			result.setMessage("系统内部错误");
		}
		return result;
	}

}
