package com.hp.user.service.scheduled;

import java.text.SimpleDateFormat;
import java.time.Duration;
import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.dubbo.common.utils.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.hp.user.service.dao.CustomerCompanyMapper;
import com.hp.user.service.dao.DictionariesMapper;
import com.hp.user.service.dao.ElectricianCertificateMapper;
import com.hp.user.service.dao.ElectricianMapper;
import com.hp.user.service.entity.CustomerCompany;
import com.hp.user.service.entity.Dictionaries;
import com.hp.user.service.entity.Electrician;
import com.hp.user.service.entity.ElectricianCertificate;
import com.hp.user.service.utils.SendSmsUtil;

/**
 * 定时任务
 * @author yeqid
 *
 */

@Component
public class Scheduler {
	
	private static final SimpleDateFormat dateFormat = new SimpleDateFormat("HH:mm:ss");
	
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	
//	@Autowired
//	private ElectricianService electricianService;
	
	@Autowired
	private ElectricianMapper electricianMapper;
	@Autowired
	private ElectricianCertificateMapper electricianCertificateMapper;
	@Autowired
	private DictionariesMapper dictionariesMapper;
	@Autowired
	private CustomerCompanyMapper customerCompanyMapper;
	@Autowired
	private SendSmsUtil sendSmsUtil;
	
	
	
	//每隔2秒执行一次
//    @Scheduled(fixedRate = 2000)
//    public void testTasks() {
//        System.out.println("定时任务执行时间：" + dateFormat.format(new Date()));
//    }

    /**
     * 每月1号0点02分执行
     * 工龄
     */
    @Scheduled(cron = "0 02 00 01 * ?")
    public void electricianWorkYear() {
    	try {
    		QueryWrapper<Electrician> queryWrapper = new QueryWrapper();
        	queryWrapper.eq("sys_deleted", 0);
        	List<Electrician> list = electricianMapper.selectList(queryWrapper);
        	if(CollectionUtils.isNotEmpty(list)) {
        		Long workingStart; 
        		LocalDateTime localDate = LocalDateTime.now();
    			LocalDateTime workingStartDate;
    			Integer workingYears ;
    			Integer workingMonths;
    			String electricianId = null;
        		for(Electrician electrician : list) {
        			try {
        				electricianId = electrician.getElectricianId();
        				workingStart = electrician.getWorkingStart();
        				if(null == workingStart) {
        					continue;
        				}
            			workingStartDate = LocalDateTime.ofEpochSecond(workingStart, 0, ZoneOffset.ofHours(8));
            			workingYears = localDate.getYear() - workingStartDate.getYear();
            			workingMonths = localDate.getMonthValue() - workingStartDate.getMonthValue()+1;
            			electrician.setWorkingYears(workingYears*12 + workingMonths);
            			electricianMapper.updateById(electrician);
        			}catch(Exception e) {
        				logger.error("定时任务计算 电工ID={},出现问题 e={}",electricianId,e);
        			}
        			
        		}
        	}
    	}catch(Exception e) {
    		logger.error("定时任务计算电工工龄出现错误，请排查原因 e={}",e);
    	}
        System.out.println("定时任务执electricianWorkYear行时间：" + dateFormat.format(new Date()));
    }
    
    /**
     * 证书到期提醒，60天，30天，15天各提醒1次
     * 每天0点0分执行
     */
    @Scheduled(cron = "0 01 00 * * *")
    public void electricianCertificate() {
    	try {
    		QueryWrapper<ElectricianCertificate> queryWrapper = new QueryWrapper();
        	List<ElectricianCertificate> list = electricianCertificateMapper.selectList(queryWrapper);
        	
        	if(CollectionUtils.isNotEmpty(list)) {
        		//查询全部证书类型
            	QueryWrapper<Dictionaries> dictionariesQueryWrapper = new QueryWrapper();
            	dictionariesQueryWrapper.eq("type", 1000);
            	List<Dictionaries> dictionariesList = dictionariesMapper.selectList(dictionariesQueryWrapper);
            	if(CollectionUtils.isNotEmpty(dictionariesList)) {
            		Map<String,String> dictionariesMap = new HashMap<>();
            		for(Dictionaries dictionaries : dictionariesList) {
            			dictionariesMap.put(dictionaries.getDictionariesId(), dictionaries.getValue());
            		}
            		//再查询全部服务商
            		QueryWrapper<CustomerCompany> customerQueryWrapper = new QueryWrapper();
            		customerQueryWrapper.eq("sys_deleted", 0);
            		customerQueryWrapper.eq("type", 0);
            		List<CustomerCompany> customerCompanyList =  customerCompanyMapper.selectList(customerQueryWrapper);
            		if(CollectionUtils.isNotEmpty(customerCompanyList)) {
            			Map<String,String> customerCompanyPhoneMap = new HashMap<>();
            			for(CustomerCompany customerCompany : customerCompanyList) {
            				customerCompanyPhoneMap.put(customerCompany.getCustomerId(), customerCompany.getPhoneNumber());
            			}
            			Long dueDate;
                		String electricianId;
                		LocalDateTime localDate = LocalDateTime.now();
            			long distance;
            			Electrician electrician;
            			String name;
            			String dictionariesId;
            			DateTimeFormatter dtf = DateTimeFormatter.ofPattern("yyyy-MM-dd");
            			LocalDateTime localDateDueDate;
            			String dictionariesName;
            			String serviceProviderPhone;
                		for(ElectricianCertificate electricianCertificate : list) {
                			dueDate = electricianCertificate.getDueDate();
                			if(null == dueDate) {
                				continue;
                			}
                			localDateDueDate = LocalDateTime.ofEpochSecond(dueDate/1000, 0, ZoneOffset.ofHours(8));
                			Duration duration = Duration.between(localDate,localDateDueDate);
                			distance = duration.toDays()+1;
                			if(distance == 60 || distance == 30 || distance == 15) {
                				electricianId = electricianCertificate.getElectricianId();
                				dictionariesId = electricianCertificate.getDictionariesId();
                				dictionariesName = dictionariesMap.get(dictionariesId);
                				if(null != dictionariesName) {
                					electrician = electricianMapper.selectById(electricianId);
                					if(null == electrician) {
                						logger.warn("electricianCertificate，电工不存在electricianId={}",electricianId);
                						continue;
                					}
                					serviceProviderPhone = customerCompanyPhoneMap.get(electrician.getServiceProviderId());
                					if(null != serviceProviderPhone) {
                						name = electrician.getName();
                        				sendSmsUtil.sendCertificateExpireMessage(serviceProviderPhone, name, dictionariesName, dtf.format(localDateDueDate));
                					}else {
                						logger.warn("electricianCertificate，查不到ServiceProviderId={}的联系人电话",electrician.getServiceProviderId());
                					}
                    				
                				}else {
                					logger.warn("electricianCertificate，查不到dictionariesId={}的证书名称",dictionariesId);
                				}
                				
                			}
                		}
            		}else {
            			logger.warn("electricianCertificate，服务商列表为空请排查原因");
            		}
            		
            	}else {
            		logger.warn("electricianCertificate，证书列表为空请排查原因");
            	}
        		
        	}
        	
    	}catch(Exception e) {
    		logger.error("定时任务筛选快到期的证书出现错误，请排查原因 e={}",e);
    	}
    	
        System.out.println("定时任务执electricianCertificate行时间：" + dateFormat.format(new Date()));
    }
    

}
